(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    697168,      14498]
NotebookOptionsPosition[    695678,      14448]
NotebookOutlinePosition[    696023,      14463]
CellTagsIndexPosition[    695980,      14460]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "st\[ODoubleDot]chiometrische Matrix"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.6704914564976673`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Das Ziel dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses ist, das mathematische Modell des Zentralmetabolismus von ",
 StyleBox["E. coli",
  FontSlant->"Italic"],
 " zu laden und aus der zugeh\[ODoubleDot]rigen st\[ODoubleDot]chiometrischen \
Matrix das in Kap. 5.2 untersuchte Netzwerk zu extrahieren.Wie zuvor laden \
wir zuerst die MASS-Toolbox."
}], "Text",
 CellChangeTimes->{{3.6774857083583603`*^9, 3.6774857192159796`*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Toolbox`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Toolbox`Style`"}]}], "Input",
 CellChangeTimes->{{3.614049483453651*^9, 3.614049492724607*^9}}],

Cell["\<\
Das Modell liegt unter dem Namen EcoliCore in den Beispieldaten der Toolbox \
vor.\
\>", "Text",
 CellChangeTimes->{{3.677485751944837*^9, 3.677485769245268*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ecoli", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Toolbox\>\"", ",", "\"\<EcoliCore\>\""}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.571783464830838*^9}],

Cell[TextData[{
 "Mit zwei einfachen Befehlen (",
 StyleBox["drawPathway",
  FontWeight->"Bold"],
 " und der Anwendung des ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Befehls ",
 StyleBox["MatrixPlot",
  FontWeight->"Bold"],
 " auf des Modell) lassen sich die metabolischen Reaktionen des Modells auf \
einer klassischen Stoffwechselkarte darstellen und die \
st\[ODoubleDot]chiometrische Matrix ",
 StyleBox["S",
  FontSlant->"Italic"],
 " des Modells visualisieren. Die Resultate sind in Abb. 5.59 \
(Stoffwechselkarte) und Abb. 5.60 (st\[ODoubleDot]chiometrische Matrix) \
dargestellt."
}], "Text",
 CellChangeTimes->{{3.677485879742262*^9, 3.677485896871092*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cmpdPos", ",", "rxnPos", ",", "textPos"}], "}"}], "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Toolbox\>\"", ",", "\"\<EcoliCoreMap\>\""}], "}"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"drawPathway", "[", 
  RowBox[{"cmpdPos", ",", "rxnPos", ",", 
   RowBox[{"textPos", "//", "Flatten"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.573830111935466*^9, 3.573830124863068*^9}, {
  3.5738303733995533`*^9, 3.573830390143231*^9}, {3.616994271052813*^9, 
  3.616994281074399*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {EdgeForm[Thickness[Tiny]], FaceForm[None]}, {
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -1575}, {1055, -1617.5}, {1055, -1668.25}, {
         1055, -1690}}], 
       BezierCurveBox[{{1055, -1775}, {1055, -1850}, {1055, -1869.6}, {
         1055, -1878}}], 
       BezierCurveBox[{{1125.03473933457, -1643.82171032361}, {
         1055, -1639.68847050625}, {1055, -1674.90654115188}, {1055, -1690}}],
        BezierCurveBox[{{1055, -1690}, {1055, -1690}, {1055, -1735}, {
        1055, -1735}}], 
       BezierCurveBox[{{1055, -1775}, {1055, -1835.20797289396}, {
         1092.70443816924, -1843.49960914133}, {
         1108.86348309891, -1847.05316753307}}], 
       BezierCurveBox[{{1055, -1775}, {1055, -1822.43416490253}, {
         1092.57268279711, -1815.15584992791}, {
         1108.67526113873, -1812.03657208165}}], 
       BezierCurveBox[{{1055, -1735}, {1055, -1735}, {1055, -1775}, {
        1055, -1775}}]},
      "\"PFK\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PFK", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4048.97029742572, -3933.08959658971}, {
         4116, -3936.74679476643}, {4116, -3902.62403842993}, {4116, -3888}}],
        BezierCurveBox[{{4116, -3848}, {4116, -3721.42986134163}, {
         4181.16248178799, -3677.28234837968}, {
         4209.08925969713, -3658.36198568171}}], 
       BezierCurveBox[{{4116, -3868}, {4116, -3868}, {4116, -3848}, {
        4116, -3848}}], 
       BezierCurveBox[{{3764.13940828905, -3650.89480836758}, {
         4116, -4114.39622346674}, {4116, -3955.91886704002}, {4116, -3888}}],
        BezierCurveBox[{{4116, -3848}, {4116, -3790.44567783389}, {
         4088.68694310698, -3778.68023142681}, {
         4076.98134729568, -3773.63789725235}}], 
       BezierCurveBox[{{4047.91020455587, -3975.48815205527}, {
         4116, -3952.04100249059}, {4116, -3907.21230074718}, {4116, -3888}}],
        BezierCurveBox[{{4116, -3888}, {4116, -3888}, {4116, -3868}, {
        4116, -3868}}], 
       BezierCurveBox[{{4220.8206228964, -4077.69052518703}, {
         4116, -4009.79490958164}, {4116, -3924.53847287449}, {4116, -3888}}]},
      "\"GLUSy\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLUSy", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1924.76950120093, -1592.94373358463}, {
         1849.02921800749, -1735}, {1741.20876540225, -1735}, {1695, -1735}}],
        BezierCurveBox[{{1945.90506626564, -2147.00952599639}, {
         1954.57898605242, -1735}, {1772.87369581572, -1735}, {1695, -1735}}],
        BezierCurveBox[{{1405, -1735}, {1205.8769224826, -1735}, {
         1120.72254766547, -1627.76470550279}, {
         1084.22781560099, -1581.80672214684}}], 
       BezierCurveBox[{{1525, -1735}, {1525, -1735}, {1405, -1735}, {
        1405, -1735}}], 
       BezierCurveBox[{{1695, -1735}, {1695, -1735}, {1525, -1735}, {
        1525, -1735}}], 
       BezierCurveBox[{{1405, -1735}, {1115.99307966763, -1735}, {
         1077.62240613798, -2024.38545028096}, {
         1061.17783176813, -2148.40778611565}}]},
      "\"TKT2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "TKT2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2211, -4944}, {2211, -4944}, {2210, -5050}, {
        2210, -5050}}], 
       BezierCurveBox[{{2211.2651216556, -4886.98138512422}, {
         2211.47170070739, -4893.99972501633}, {
         2211.14151021222, -4928.9999175049}, {2211, -4944}}]},
      "\"EX_acald(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_acald(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3989, -4714}, {3989, -4677.5}, {3989, -4621.85}, {
         3989, -4598}}], 
       BezierCurveBox[{{3989, -4598}, {3989, -4519.5}, {3989, -4497.45}, {
         3989, -4488}}]},
      "\"NH4t\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "NH4t", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1460, -4925}, {1460, -4925}, {1460, -5055}, {
        1460, -5055}}], 
       BezierCurveBox[{{1460, -4853}, {1460, -4867.5}, {1460, -4907.75}, {
         1460, -4925}}]},
      "\"EX_for(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_for(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4822.60353245644, -3670.08713103796}, {
         4820.04875150355, -3635}, {4791.31462545106, -3635}, {4779, -3635}}],
        BezierCurveBox[{{4541, -3635}, {4394.49232102036, -3635}, {
         4324.84079959371, -3633.57361421524}, {
         4294.99014755372, -3632.96230602177}}], 
       BezierCurveBox[{{4645, -3635}, {4645, -3635}, {4541, -3635}, {
        4541, -3635}}], 
       BezierCurveBox[{{4840.00794971347, -3634.82680841848}, {
         4831.00240379059, -3635}, {4794.60072113718, -3635}, {4779, -3635}}],
        BezierCurveBox[{{4779, -3635}, {4779, -3635}, {4645, -3635}, {
        4645, -3635}}], 
       BezierCurveBox[{{4541, -3635}, {4499.83569507449, -3635}, {
         4494.41682827142, -3648.15277299776}, {
         4492.09445678439, -3653.78967571108}}]},
      "\"GLUt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLUt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -4125}, {1055, -4035}, {1055, -4004.9}, {
         1055, -3992}}], 
       BezierCurveBox[{{987.215583835287, -4262.15235332961}, {
         1055, -4277.20153254455}, {1055, -4240.66045976337}, {1055, -4225}}],
        BezierCurveBox[{{1055, -4225}, {1055, -4225}, {1055, -4175}, {
        1055, -4175}}], 
       BezierCurveBox[{{1055, -4125}, {1055, -4060.96875762567}, {
         1010.57595775345, -4053.87478999179}, {
         991.537082504935, -4050.8345181487}}], 
       BezierCurveBox[{{1055, -4125}, {1055, -4072.79846745545}, {
         1010.28435216163, -4082.72602656279}, {
         991.12050308805, -4086.98069475165}}], 
       BezierCurveBox[{{1055, -4175}, {1055, -4175}, {1055, -4125}, {
        1055, -4125}}], 
       BezierCurveBox[{{1055, -4302}, {1055, -4285}, {1055, -4243}, {
        1055, -4225}}]},
      "\"LDH_D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "LDH_D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3666, -3063}, {3706.57852616775, -3112.85361786323}, {
         3746.63054992913, -3084.51547090933}, {
         3763.79570296972, -3072.37055078622}}], 
       BezierCurveBox[{{3631, -3020}, {3631, -3020}, {3666, -3063}, {
        3666, -3063}}], 
       BezierCurveBox[{{3491.01613764367, -2948.73060757321}, {
         3542.9201794084, -2929.87181148767}, {
         3574.47605382252, -2962.1615434463}, {3588, -2976}}], 
       BezierCurveBox[{{3460.17636702911, -2882.3251274821}, {
         3518.01503039268, -2904.38747295995}, {
         3567.0045091178, -2954.51624188798}, {3588, -2976}}], 
       BezierCurveBox[{{3516.36401388435, -3001.34308024939}, {
         3551.91853851885, -2939.07943476348}, {
         3577.17556155566, -2964.92383042904}, {3588, -2976}}], 
       BezierCurveBox[{{3666, -3063}, {3702.28163371939, -3107.57457856954}, {
         3722.5947545003, -3110.17882168806}, {
         3731.30037769211, -3111.29492588172}}], 
       BezierCurveBox[{{3588, -2976}, {3588, -2976}, {3631, -3020}, {
        3631, -3020}}], 
       BezierCurveBox[{{3666, -3063}, {3713.05936687909, -3120.81579359431}, {
         3720.09128699707, -3140.38330263923}, {
         3723.10496704763, -3148.7693779442}}]},
      "\"SUCOAS\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "SUCOAS", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1289.89532521299, -4772.04353484663}, {
         1360, -4779.24428900898}, {1360, -4744.77328670269}, {1360, -4730}}],
        BezierCurveBox[{{1430.37533850951, -4805.26930960916}, {
         1360, -4794.03124237433}, {1360, -4749.2093727123}, {1360, -4730}}], 
       BezierCurveBox[{{1360, -4730}, {1360, -4730}, {1360, -4600}, {
        1360, -4600}}], 
       BezierCurveBox[{{1360, -4600}, {1360, -4600}, {1360, -4470}, {
        1360, -4470}}], 
       BezierCurveBox[{{1360, -4470}, {1360, -4275.94781629675}, {
         1414.08641941048, -4178.07962146038}, {
         1437.26631344355, -4136.13610938765}}], 
       BezierCurveBox[{{1360, -4470}, {1360, -4422.56583509747}, {
         1322.42731720289, -4429.84415007209}, {
         1306.32473886127, -4432.96342791835}}]},
      "\"FORt2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FORt2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2220, -3410}, {1646.68507781499, -3696.6574610925}, {
         1262.84175760593, -3857.76448957364}, {
         1098.33747751633, -3926.81035892269}}], 
       BezierCurveBox[{{2412.8449955826, -3359.71866626166}, {
         2361.62791082806, -3329.02325350316}, {
         2325.48837324842, -3350.70697605095}, {2310, -3360}}], 
       BezierCurveBox[{{2260, -3390}, {2260, -3390}, {2220, -3410}, {
        2220, -3410}}], 
       BezierCurveBox[{{2310, -3360}, {2310, -3360}, {2260, -3390}, {
        2260, -3390}}], 
       BezierCurveBox[{{2593.9896864, -3205.0553804705}, {
         2461.55141333011, -3269.06915200194}, {
         2355.46542399903, -3332.72074560058}, {2310, -3360}}], 
       BezierCurveBox[{{2220, -3410}, {2171.83362168483, -3434.08318915758}, {
         2213.92340814071, -3470.32514916354}, {
         2231.96188805037, -3485.85741773753}}], 
       BezierCurveBox[{{2220, -3410}, {2161.17823532059, -3439.41088233971}, {
         2179.02795286341, -3485.66038575474}, {
         2186.67783181033, -3505.48160150403}}]},
      "\"ME2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ME2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1977, -1265}, {2041.03124237433, -1265}, {
         2048.12521000821, -1220.57595775345}, {
         2051.1654818513, -1201.53708250494}}], 
       BezierCurveBox[{{1957, -1265}, {1957, -1265}, {1977, -1265}, {
        1977, -1265}}], 
       BezierCurveBox[{{1902.6652404063, -1184.52459626381}, {
         1884.79846745545, -1265}, {1921.33954023663, -1265}, {1937, -1265}}],
        BezierCurveBox[{{1977, -1265}, {2066, -1265}, {2095.4, -1265}, {
         2108, -1265}}], 
       BezierCurveBox[{{1977, -1265}, {2029.20153254455, -1265}, {
         2019.27397343721, -1220.28435216163}, {
         2015.01930524835, -1201.12050308805}}], 
       BezierCurveBox[{{1857, -1265}, {1882, -1265}, {1920.5, -1265}, {
         1937, -1265}}], 
       BezierCurveBox[{{1937, -1265}, {1937, -1265}, {1957, -1265}, {
        1957, -1265}}]},
      "\"GND\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GND", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3417, -3766}, {3417, -3612.22662779272}, {
         3283.48990688911, -3588.43894421312}, {
         3226.27129555587, -3578.24422267901}}], 
       BezierCurveBox[{{3415.0133966725, -3946.06763901996}, {
         3417, -3916.53360395609}, {3417, -3874.86008118683}, {3417, -3857}}],
        BezierCurveBox[{{3417, -3857}, {3417, -3857}, {3417, -3766}, {
        3417, -3766}}], 
       BezierCurveBox[{{3417, -3766}, {3417, -3316.4974972261}, {
         3418.88042635956, -3034.74851644563}, {
         3419.6863233708, -2913.99895325401}}]},
      "\"ICL\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ICL", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4807, -1660}, {4755, -1660}, {4688.5, -1660}, {
         4660, -1660}}], 
       BezierCurveBox[{{4660, -1660}, {4495, -1660}, {4412.4, -1660}, {
         4377, -1660}}]},
      "\"O2t\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "O2t", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3621, -4711}, {3621, -4679}, {3621, -4626.5}, {
         3621, -4604}}], 
       BezierCurveBox[{{3621, -4604}, {3621, -4519}, {3621, -4492.4}, {
         3621, -4481}}]},
      "\"CO2t\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "CO2t", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4420, -1900}, {4515, -1900}, {4595.5, -1900}, {
         4630, -1900}}], 
       BezierCurveBox[{{4630, -1900}, {4630, -1900}, {4660, -1900}, {
        4660, -1900}}], 
       BezierCurveBox[{{4690, -1900}, {4810.41594578792, -1900}, {
         4622.98473037651, -1800.17509094875}, {
         4542.65706662876, -1757.39298706964}}], 
       BezierCurveBox[{{4597.95294057437, -2192.52513222606}, {
         4469.68780458119, -1900}, {4581.90634137436, -1900}, {4630, -1900}}],
        BezierCurveBox[{{4690, -1900}, {4775, -1900}, {4808.6, -1900}, {
         4823, -1900}}], 
       BezierCurveBox[{{4690, -1900}, {4776.31338250816, -1900}, {
         4747.23947764333, -1987.76890335622}, {
         4734.77923270127, -2025.38414765174}}], 
       BezierCurveBox[{{4660, -1900}, {4660, -1900}, {4690, -1900}, {
        4690, -1900}}], 
       BezierCurveBox[{{4342.30205357194, -1687.36164245642}, {
         4437.90627287701, -1900}, {4572.3718818631, -1900}, {4630, -1900}}]},
      "\"CYTBD\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "CYTBD", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -1995}, {1055, -1995}, {1055, -2045}, {
        1055, -2045}}], 
       BezierCurveBox[{{1055, -2045}, {1055, -2120}, {1055, -2139.6}, {
         1055, -2148}}], 
       BezierCurveBox[{{1055, -2045}, {1055, -2170}, {
         947.64594214388, -2183.41925723201}, {
         901.637060205542, -2189.17036747431}}], 
       BezierCurveBox[{{1055, -1960}, {1055, -1968}, {1055, -1984.5}, {
         1055, -1995}}]},
      "\"FBA\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FBA", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4986, -2230}, {4986, -2230}, {5116, -2230}, {
        5116, -2230}}], 
       BezierCurveBox[{{4892.99535084873, -2229.632301664}, {
         4917.99816178955, -2230}, {4965.59944853687, -2230}, {4986, -2230}}]},
      "\"EX_h(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_h(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3213.68662204878, -2749.6572840919}, {
         3225.97824425027, -2815.19693159803}, {
         3193.79347327508, -2816.45907947941}, {3180, -2817}}], 
       BezierCurveBox[{{3078, -2826}, {3026.61653595408, -2833.05263232003}, {
         3023.82195020627, -2793.75056219105}, {
         3022.62427060006, -2776.90681785006}}], 
       BezierCurveBox[{{3180, -2817}, {3180, -2817}, {3129, -2819}, {
        3129, -2819}}], 
       BezierCurveBox[{{3392.8111080382, -2854.32071950427}, {
         3302.482361925, -2812.19677012059}, {
         3216.7447085775, -2815.55903103618}, {3180, -2817}}], 
       BezierCurveBox[{{3129, -2819}, {3129, -2819}, {3078, -2826}, {
        3078, -2826}}], 
       BezierCurveBox[{{3078, -2826}, {2952.6240893861, -2843.20845831955}, {
         2902.83364114806, -2878.08660693243}, {
         2881.49487761747, -2893.03438490938}}]},
      "\"SUCDi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "SUCDi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3510, -870}, {3510, -1002.85330255586}, {
         3552.95630843379, -1058.76652108264}, {
         3571.36615490541, -1082.72932902269}}], 
       BezierCurveBox[{{3510, -820}, {3510, -820}, {3510, -870}, {
        3510, -870}}], 
       BezierCurveBox[{{3510, -670}, {3510, -725}, {3510, -777.5}, {
         3510, -800}}], 
       BezierCurveBox[{{3510, -800}, {3510, -800}, {3510, -820}, {
        3510, -820}}], 
       BezierCurveBox[{{3337.26045922983, -1240.89182706228}, {
         3510, -548.355409356768}, {3510, -724.50662280703}, {3510, -800}}], 
       BezierCurveBox[{{3510, -870}, {3510, -1100.70543990119}, {
         3644.50381179445, -1199.70876011578}, {
         3702.1483025635, -1242.13875449346}}], 
       BezierCurveBox[{{3510, -870}, {3510, -955}, {3510, -988.6}, {
         3510, -1003}}], 
       BezierCurveBox[{{3425.46042154853, -1090.50112211435}, {
         3510, -633.792298614053}, {3510, -750.137689584216}, {3510, -800}}]},
      "\"THD2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "THD2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{955, -2195}, {1005, -2195}, {1007.1, -2195}, {
         1008, -2195}}], 
       BezierCurveBox[{{898, -2195}, {905, -2195}, {940, -2195}, {
        955, -2195}}]},
      "\"TPI\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "TPI", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3991, -4918}, {3991, -4918}, {3991, -5056}, {
        3991, -5056}}], 
       BezierCurveBox[{{3990.06807577339, -4799.9867330015}, {
         3991, -4837.49378905948}, {3991, -4893.84813671784}, {3991, -4918}}]},
      "\"EX_nh4(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_nh4(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -2725}, {1055, -2725}, {1055, -2665}, {
        1055, -2665}}], 
       BezierCurveBox[{{1055, -2832}, {1055, -2825}, {1055, -2790}, {
        1055, -2775}}], 
       BezierCurveBox[{{1112.60225993454, -2811.27586158634}, {
         1055, -2822.43416490253}, {1055, -2789.23024947076}, {1055, -2775}}],
        BezierCurveBox[{{1055, -2775}, {1055, -2775}, {1055, -2725}, {
        1055, -2725}}], 
       BezierCurveBox[{{1055, -2665}, {1055, -2617.56583509747}, {
         1092.57268279711, -2624.84415007209}, {
         1108.67526113873, -2627.96342791835}}], 
       BezierCurveBox[{{1055, -2665}, {1055, -2615}, {1055, -2612.9}, {
         1055, -2612}}]},
      "\"PGK\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PGK", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -1308}, {1055, -1330}, {1055, -1375.5}, {
         1055, -1395}}], 
       BezierCurveBox[{{1055, -1395}, {1055, -1470}, {1055, -1489.6}, {
         1055, -1498}}]},
      "\"PGI\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PGI", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3512, -3923}, {3512, -3923}, {3606, -3846}, {
        3606, -3846}}], 
       BezierCurveBox[{{3454.0307937877, -3963.13633173814}, {
         3468.56511504228, -3958.57963980579}, {
         3498.96953451268, -3933.67389194174}, {3512, -3923}}], 
       BezierCurveBox[{{3663, -3781}, {3702.91083896511, -3735.48763977663}, {
         3685.19614747184, -3705.03410525728}, {
         3677.60413683187, -3691.98259046327}}], 
       BezierCurveBox[{{3663, -3781}, {3690.36389556158, -3749.79555769294}, {
         3663.65336087537, -3734.68893780456}, {
         3652.205988867, -3728.21467213811}}], 
       BezierCurveBox[{{3482.84200836735, -4034.32129012719}, {
         3456.68286977151, -3968.31296837865}, {
         3495.40486093145, -3936.5938905136}, {3512, -3923}}], 
       BezierCurveBox[{{3663, -3781}, {3720.67193262716, -3715.2337610392}, {
         3729.32402269977, -3685.09303072927}, {
         3733.03206130232, -3672.17557488216}}], 
       BezierCurveBox[{{3606, -3846}, {3606, -3846}, {3663, -3781}, {
        3663, -3781}}]},
      "\"ICDHyr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ICDHyr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1739.51410701472, -3927.7066903899}, {
         2360.88885683682, -3489.36211083341}, {
         2629.06665705105, -3732.70863325002}, {2744, -3837}}], 
       BezierCurveBox[{{2672.3826809083, -3750.84965272972}, {
         2691.64233405342, -3789.49026608551}, {
         2728.29270021602, -3822.74707982565}, {2744, -3837}}], 
       BezierCurveBox[{{2840, -3918}, {2910.12103954245, -3971.4255539371}, {
         2854.24466231844, -4035.59497525602}, {
         2830.29764350815, -4063.09615582127}}], 
       BezierCurveBox[{{2625.45782569734, -3847.30923072818}, {
         2693.65687604278, -3791.31827640919}, {
         2728.89706281283, -3823.29548292276}, {2744, -3837}}], 
       BezierCurveBox[{{2744, -3837}, {2744, -3837}, {2798, -3886}, {
        2798, -3886}}], 
       BezierCurveBox[{{2840, -3918}, {2898.70183699975, -3962.72520914266}, {
         2917.99336970043, -3968.93569043697}, {
         2926.26116942929, -3971.59732527739}}], 
       BezierCurveBox[{{2798, -3886}, {2798, -3886}, {2840, -3918}, {
        2840, -3918}}], 
       BezierCurveBox[{{2840, -3918}, {2922.32814368409, -3980.72620471169}, {
         2909.33122110957, -4050.65394945243}, {
         2903.76111143478, -4080.62298291274}}]},
      "\"CS\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "CS", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3140, -2600}, {3333.44831351035, -2600}, {
         3383.88924043144, -2755.60329364051}, {
         3405.50678054048, -2822.29041948644}}], 
       BezierCurveBox[{{3017.70697375816, -2720.13188406883}, {
         3003.84226894136, -2600}, {3057.15268068241, -2600}, {3080, -2600}}],
        BezierCurveBox[{{2846.52813151266, -2890.2081842106}, {
         2880.89638375961, -2600}, {3020.26891512788, -2600}, {3080, -2600}}],
        BezierCurveBox[{{3140, -2600}, {3213.82411530117, -2600}, {
         3211.90878660271, -2665.11119858834}, {
         3211.08793144623, -2693.01599798334}}], 
       BezierCurveBox[{{3080, -2600}, {3080, -2600}, {3110, -2600}, {
        3110, -2600}}], 
       BezierCurveBox[{{3110, -2600}, {3110, -2600}, {3140, -2600}, {
        3140, -2600}}]},
      "\"FRD7\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FRD7", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4330, -2570}, {4470, -2570}, {4582, -2570}, {
        4630, -2570}}], 
       BezierCurveBox[{{4710, -2570}, {4780, -2570}, {4803.1, -2570}, {
         4813, -2570}}], 
       BezierCurveBox[{{4710, -2570}, {4860.41608956491, -2570}, {
         4577.60782760281, -2621.37110449193}, {
         4456.40428676191, -2643.38729213133}}], 
       BezierCurveBox[{{4710, -2570}, {4892.00274723201, -2570}, {
         4715.24255396923, -2350.61891861261}, {
         4639.48818542803, -2256.59845516087}}], 
       BezierCurveBox[{{4702.99515046971, -2094.71507824086}, {
         4375.98228408239, -2570}, {4553.79468522472, -2570}, {4630, -2570}}],
        BezierCurveBox[{{4630, -2570}, {4630, -2570}, {4670, -2570}, {
        4670, -2570}}], 
       BezierCurveBox[{{4670, -2570}, {4670, -2570}, {4710, -2570}, {
        4710, -2570}}], 
       BezierCurveBox[{{4434.57388992939, -2493.6967781732}, {
         4515.76340341204, -2570}, {4595.72902102361, -2570}, {4630, -2570}}]},
      "\"NADH16\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "NADH16", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3091, -4016}, {3140.53820979637, -4023.43073146946}, {
         3148.61576461952, -4012.49383123106}, {
         3152.07757382944, -4007.80658827175}}], 
       BezierCurveBox[{{3071, -4013}, {3071, -4013}, {3091, -4016}, {
        3091, -4016}}], 
       BezierCurveBox[{{3091, -4016}, {3151.51328937274, -4025.07699340591}, {
         3162.24933837977, -4053.31391696908}, {
         3166.85050223992, -4065.415455639}}], 
       BezierCurveBox[{{3010.97954588102, -4001.83148480553}, {
         3019.78254805378, -4005.31738220807}, {
         3055.63476441613, -4010.69521466242}, {3071, -4013}}]},
      "\"ACONTa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACONTa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4246.27648888853, -4064.00127412881}, {
         4247, -3985.50115206762}, {4247, -3909.55034562029}, {4247, -3877}}],
        BezierCurveBox[{{4247, -3815}, {4247, -3777.16813512395}, {
         4234.13498853328, -3773.55446415546}, {
         4228.6214121904, -3772.00574802611}}], 
       BezierCurveBox[{{4218.73220356819, -3930.7496510003}, {
         4247, -3916.00320499651}, {4247, -3888.70096149895}, {4247, -3877}}],
        BezierCurveBox[{{4247, -3815}, {4247, -3723.49863388998}, {
         4247.34045326259, -3692.34762546006}, {
         4247.48636180369, -3678.9971932758}}], 
       BezierCurveBox[{{4247, -3877}, {4247, -3877}, {4247, -3857}, {
        4247, -3857}}], 
       BezierCurveBox[{{4247, -3857}, {4247, -3857}, {4247, -3815}, {
        4247, -3815}}]},
      "\"GLUN\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLUN", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -2238}, {1055, -2270}, {1055, -2322.5}, {
         1055, -2345}}], 
       BezierCurveBox[{{1112.77013357471, -2272.08771544348}, {
         1055, -2284.79202710604}, {1055, -2326.93760813181}, {1055, -2345}}],
        BezierCurveBox[{{1055, -2435}, {1055, -2482.43416490253}, {
         1092.57268279711, -2475.15584992791}, {
         1108.67526113873, -2472.03657208165}}], 
       BezierCurveBox[{{1055, -2395}, {1055, -2395}, {1055, -2435}, {
        1055, -2435}}], 
       BezierCurveBox[{{1055, -2435}, {1055, -2500}, {1055, -2512.6}, {
         1055, -2518}}], 
       BezierCurveBox[{{1055, -2435}, {1055, -2495.20797289396}, {
         1092.70443816924, -2503.49960914133}, {
         1108.86348309891, -2507.05316753307}}], 
       BezierCurveBox[{{1112.60225993454, -2308.72413841366}, {
         1055, -2297.56583509747}, {1055, -2330.76975052924}, {1055, -2345}}],
        BezierCurveBox[{{1055, -2345}, {1055, -2345}, {1055, -2395}, {
        1055, -2395}}]},
      "\"GAPD\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GAPD", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -4792}, {1055, -4785}, {1055, -4750}, {
        1055, -4735}}], 
       BezierCurveBox[{{1055, -4595}, {1055, -4595}, {1055, -4445}, {
        1055, -4445}}], 
       BezierCurveBox[{{1055, -4445}, {1055, -4392.79846745545}, {
         1010.28435216163, -4402.72602656279}, {
         991.12050308805, -4406.98069475165}}], 
       BezierCurveBox[{{987.215583835287, -4772.15235332961}, {
         1055, -4787.20153254455}, {1055, -4750.66045976337}, {1055, -4735}}],
        BezierCurveBox[{{1055, -4735}, {1055, -4735}, {1055, -4595}, {
        1055, -4595}}], 
       BezierCurveBox[{{1055, -4445}, {1055, -4395}, {1055, -4392.9}, {
         1055, -4392}}]},
      "\"D_LACt2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "D_LACt2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3776, -3330}, {3770.87026239352, -3277.23698461907}, {
         3815.83705162416, -3280.68876729635}, {
         3835.10853272301, -3282.16810272948}}], 
       BezierCurveBox[{{3703.39456022138, -3510.8837520227}, {
         3778.08874900798, -3529.69252579257}, {
         3779.42662470239, -3494.90775773777}, {3780, -3480}}], 
       BezierCurveBox[{{3757.94997964274, -3599.48276927927}, {
         3777.10059090215, -3555.38463654408}, {
         3779.13017727065, -3502.61539096322}, {3780, -3480}}], 
       BezierCurveBox[{{3783, -3402}, {3783, -3402}, {3776, -3330}, {
        3776, -3330}}], 
       BezierCurveBox[{{3780, -3480}, {3780, -3480}, {3783, -3402}, {
        3783, -3402}}], 
       BezierCurveBox[{{3776, -3330}, {3769.13404669886, -3259.37876604543}, {
         3761.64007133104, -3242.87116443913}, {
         3758.42836760198, -3235.79647803643}}], 
       BezierCurveBox[{{3703.70718266286, -3554.59016840697}, {
         3777.62304267082, -3541.80089055876}, {
         3779.28691280125, -3498.54026716763}, {3780, -3480}}], 
       BezierCurveBox[{{3776, -3330}, {3770.84658725615, -3276.99346892041}, {
         3785.95497732026, -3263.47110187365}, {
         3792.43000163346, -3257.67580171076}}]},
      "\"AKGDH\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "AKGDH", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4415, -4158}, {4324.64376059176, -4158}, {
         4295.11108201341, -4133.96641596496}, {
         4282.45421976555, -4123.66630852136}}], 
       BezierCurveBox[{{4455, -4158}, {4455, -4158}, {4435, -4158}, {
        4435, -4158}}], 
       BezierCurveBox[{{4415, -4158}, {4332.99390266572, -4158}, {
         4310.60474831049, -4204.64999741981}, {
         4301.00939644397, -4224.64285345687}}], 
       BezierCurveBox[{{4852, -4158}, {4668.5, -4158}, {4519.05, -4158}, {
         4455, -4158}}], 
       BezierCurveBox[{{4435, -4158}, {4435, -4158}, {4415, -4158}, {
        4415, -4158}}], 
       BezierCurveBox[{{4415, -4158}, {4350.96875762567, -4158}, {
         4343.87478999179, -4202.42404224655}, {
         4340.8345181487, -4221.46291749507}}], 
       BezierCurveBox[{{4531.84620640611, -4238.25022567301}, {
         4519.03124237433, -4158}, {4474.2093727123, -4158}, {4455, -4158}}], 
       BezierCurveBox[{{4415, -4158}, {4362.79846745545, -4158}, {
         4372.72602656279, -4202.71564783837}, {
         4376.98069475165, -4221.87949691195}}], 
       BezierCurveBox[{{4489.3347595937, -4238.47540373619}, {
         4507.20153254455, -4158}, {4470.66045976337, -4158}, {4455, -4158}}]},
      "\"GLNabc\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLNabc", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1715, -4465}, {1715, -4412.79846745545}, {
         1759.71564783837, -4422.72602656279}, {
         1778.87949691195, -4426.98069475165}}], 
       BezierCurveBox[{{1715, -4465}, {1715, -4425}, {1715, -4432}, {
         1715, -4429.9}}], 
       BezierCurveBox[{{1715, -4745}, {1715, -4745}, {1715, -4585}, {
        1715, -4585}}], 
       BezierCurveBox[{{1715, -4585}, {1715, -4585}, {1715, -4465}, {
        1715, -4465}}], 
       BezierCurveBox[{{1782.78441616471, -4782.15235332961}, {
         1715, -4797.20153254455}, {1715, -4760.66045976337}, {1715, -4745}}],
        BezierCurveBox[{{1715, -4802}, {1715, -4795}, {1715, -4760}, {
        1715, -4745}}]},
      "\"ACt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2603.17294006135, -3231.13049876942}, {
         2588.09272574144, -3264.23165565782}, {
         2583.82781772243, -3317.96949669735}, {2582, -3341}}], 
       BezierCurveBox[{{2578, -3456}, {2578.94389761029, -3505.08267573494}, {
         2609.83069835014, -3506.95644476985}, {
         2623.06789866722, -3507.75948864195}}], 
       BezierCurveBox[{{2582, -3341}, {2582, -3341}, {2577, -3404}, {
        2577, -3404}}], 
       BezierCurveBox[{{2578, -3456}, {2579.5809926922, -3538.21161999442}, {
         2626.39754490216, -3560.02492699751}, {
         2646.46178156358, -3569.3734871417}}], 
       BezierCurveBox[{{2637.54422339598, -3304.03153578967}, {
         2585.69079876087, -3294.49593561304}, {
         2583.10723962826, -3327.04878068391}, {2582, -3341}}], 
       BezierCurveBox[{{2577, -3404}, {2577, -3404}, {2578, -3456}, {
        2578, -3456}}], 
       BezierCurveBox[{{2578, -3456}, {2580.69155247274, -3595.96072858229}, {
         2618.34183014046, -3657.52131717105}, {
         2634.47766342663, -3683.90442656623}}]},
      "\"MDH\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "MDH", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1715, -4105}, {1715, -4157.20153254455}, {
         1759.71564783837, -4147.27397343721}, {
         1778.87949691195, -4143.01930524835}}], 
       BezierCurveBox[{{1715, -4085}, {1715, -4085}, {1715, -4105}, {
        1715, -4105}}], 
       BezierCurveBox[{{1715, -3988}, {1715, -4005}, {1715, -4047}, {
        1715, -4065}}], 
       BezierCurveBox[{{1715, -4105}, {1715, -4140}, {1715, -4128}, {
         1715, -4131.6}}], 
       BezierCurveBox[{{1782.78441616471, -4027.84764667039}, {
         1715, -4012.79846745545}, {1715, -4049.33954023663}, {1715, -4065}}],
        BezierCurveBox[{{1715, -4065}, {1715, -4065}, {1715, -4085}, {
        1715, -4085}}]},
      "\"PTAr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PTAr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1177.20621786911, -4029.15676026401}, {
         1203.52184929507, -3995}, {1239.55655478852, -3995}, {1255, -3995}}],
        BezierCurveBox[{{1415, -3995}, {1469.82928049865, -3995}, {
         1466.1671079266, -4032.25778883358}, {
         1464.59760539573, -4048.2254126194}}], 
       BezierCurveBox[{{1255, -3995}, {1255, -3995}, {1335, -3995}, {
        1335, -3995}}], 
       BezierCurveBox[{{1081.66135958015, -3958.75397780054}, {
         1151.92235935956, -3995}, {1224.07670780787, -3995}, {1255, -3995}}],
        BezierCurveBox[{{1415, -3995}, {1567.06906325746, -3995}, {
         1639.45290589943, -3970.53458247616}, {
         1670.47455274599, -3960.04940353737}}], 
       BezierCurveBox[{{1335, -3995}, {1335, -3995}, {1415, -3995}, {
        1415, -3995}}]},
      "\"PFL\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PFL", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1025.02861598684, -3943.68998460488}, {
         835, -3935.38404810405}, {835, -3844.11521443122}, {835, -3805}}], 
       BezierCurveBox[{{835, -3805}, {835, -3805}, {835, -3645}, {
        835, -3645}}], 
       BezierCurveBox[{{835, -3525}, {835, -3391.86473044306}, {
         956.196243278683, -3382.57408510848}, {
         1008.13749039812, -3378.5923799651}}], 
       BezierCurveBox[{{835, -3525}, {835, -3469.09830056251}, {
         790.85501256173, -3471.70360503783}, {
         771.935732231043, -3472.82016409869}}], 
       BezierCurveBox[{{835, -3525}, {835, -3454.28932188135}, {
         789.855789240551, -3441.06688868122}, {
         770.508270343645, -3435.40013159545}}], 
       BezierCurveBox[{{835, -3645}, {835, -3645}, {835, -3525}, {
        835, -3525}}], 
       BezierCurveBox[{{835, -3525}, {835, -3475}, {
         788.165664246898, -3498.41716787655}, {
         768.093806066997, -3508.4530969665}}], 
       BezierCurveBox[{{752.888543819998, -3813.94427191}, {835, -3855}, {
         835, -3820}, {835, -3805}}], 
       BezierCurveBox[{{754.965260665429, -3856.17828967639}, {
         835, -3860.90169943749}, {835, -3821.77050983125}, {835, -3805}}]},
      "\"PPS\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PPS", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -3225}, {1055, -3225}, {1055, -3265}, {
        1055, -3265}}], 
       BezierCurveBox[{{1055, -3265}, {1055, -3320}, {1055, -3325.6}, {
         1055, -3328}}], 
       BezierCurveBox[{{1055, -3168}, {1055, -3175}, {1055, -3210}, {
        1055, -3225}}], 
       BezierCurveBox[{{1055, -3265}, {1055, -3319.08326913196}, {
         1017.84421166307, -3321.52594468507}, {
         1001.92030237581, -3322.5728056364}}]},
      "\"ENO\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ENO", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1335, -3503}, {1188.96438790487, -3454.32146263496}, {
         1123.49891558465, -3415.55879519967}, {
         1095.44228459027, -3398.94622344169}}], 
       BezierCurveBox[{{1404, -3526}, {1404, -3526}, {1335, -3503}, {
        1335, -3503}}], 
       BezierCurveBox[{{1485, -3554}, {1485, -3554}, {1404, -3526}, {
        1404, -3526}}], 
       BezierCurveBox[{{1335, -3503}, {1304.02581720206, -3492.67527240069}, {
         1299.55833317314, -3504.96172939674}, {
         1297.64369716074, -3510.22735382362}}], 
       BezierCurveBox[{{1509.88788152201, -3605.60648009703}, {
         1519.85768059594, -3566.04956860106}, {
         1495.45730417878, -3557.61487058032}, {1485, -3554}}], 
       BezierCurveBox[{{1335, -3503}, {1277.79510510455, -3483.93170170152}, {
         1257.05267871819, -3494.19415590607}, {
         1248.16306740975, -3498.59235056517}}], 
       BezierCurveBox[{{2629.02251436562, -3725.16204777907}, {
         2045.57449307587, -3747.77883711265}, {
         1653.17234792276, -3612.13365113379}, {1485, -3554}}]},
      "\"PPCK\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PPCK", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3298, -4011}, {3356.81483103889, -3998.6179303076}, {
         3365.62458751253, -3995.07147024292}, {
         3369.40019742981, -3993.55155878663}}], 
       BezierCurveBox[{{3279, -4015}, {3279, -4015}, {3298, -4011}, {
        3298, -4011}}], 
       BezierCurveBox[{{3194.55168266742, -4070.38161835031}, {
         3215.15759414663, -4028.44050649545}, {
         3259.84727824399, -4019.03215194863}, {3279, -4015}}], 
       BezierCurveBox[{{3207.16149573054, -4003.33546384378}, {
         3225.79262082249, -4026.20155351105}, {
         3263.03778624675, -4018.36046605332}, {3279, -4015}}]},
      "\"ACONTb\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACONTb", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2500, -4873}, {2500, -4880}, {2500, -4915}, {
        2500, -4930}}], 
       BezierCurveBox[{{2500, -4930}, {2500, -4930}, {2500, -5040}, {
        2500, -5040}}]},
      "\"EX_etoh(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_etoh(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1064.63244787989, -734.955552305365}, {
         1070.33683947301, -839.631605269947}, {
         1061.0010518419, -932.989481580984}, {1057, -973}}], 
       BezierCurveBox[{{955.140818251448, -1077.76156024487}, {
         1065.23960491219, -890.603950878145}, {
         1059.47188147366, -948.281185263444}, {1057, -973}}], 
       BezierCurveBox[{{1057, -973}, {1057, -973}, {1055, -993}, {
        1055, -993}}], 
       BezierCurveBox[{{1055, -983}, {1055, -907.926702483506}, {
         1112.79013703663, -1016.03661747722}, {
         1137.55733862375, -1062.36943818882}}], 
       BezierCurveBox[{{1055, -983}, {1055, -842}, {1055, -1105.2}, {
         1055, -1218}}], 
       BezierCurveBox[{{1055, -993}, {1055, -993}, {1055, -983}, {
        1055, -983}}]},
      "\"GLCpts\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLCpts", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4078, -3632}, {4036.85391877712, -3632}, {
         4038.65938663626, -3606.03759952667}, {
         4039.4331585759, -3594.91085646668}}], 
       BezierCurveBox[{{4148.51272866646, -3590.35095617315}, {
         4156.89730067755, -3632}, {4129.66919020327, -3632}, {4118, -3632}}],
        BezierCurveBox[{{4205, -3632}, {4183, -3632}, {4137.5, -3632}, {
         4118, -3632}}], 
       BezierCurveBox[{{4098, -3632}, {4098, -3632}, {4078, -3632}, {
        4078, -3632}}], 
       BezierCurveBox[{{4118, -3632}, {4118, -3632}, {4098, -3632}, {
        4098, -3632}}], 
       BezierCurveBox[{{4078, -3632}, {4021.27258158527, -3632}, {
         4010.30885907035, -3604.28411632433}, {
         4005.61012084967, -3592.40588046333}}], 
       BezierCurveBox[{{4182.72420695541, -3589.6695384146}, {
         4170.3259018078, -3632}, {4133.69777054234, -3632}, {4118, -3632}}], 
       BezierCurveBox[{{4078, -3632}, {3911.98117576612, -3632}, {
         3828.67943534185, -3629.4906268726}, {
         3792.97868944574, -3628.41518124658}}], 
       BezierCurveBox[{{4078, -3632}, {4000.58553106815, -3632}, {
         3975.65223630996, -3600.50649335312}, {
         3964.96653855645, -3587.00927621874}}]},
      "\"GLUDy\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLUDy", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3257, -4924}, {3257, -4924}, {3257, -5064}, {
        3257, -5064}}], 
       BezierCurveBox[{{3257, -4797}, {3257, -4839}, {3257, -4898.5}, {
         3257, -4924}}]},
      "\"EX_h2o(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_h2o(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4924.88847442718, -2909.14491729319}, {
         4896.13116398005, -3027}, {4826.03934919402, -3027}, {4796, -3027}}],
        BezierCurveBox[{{4796, -3027}, {4796, -3027}, {4666, -3027}, {
        4666, -3027}}], 
       BezierCurveBox[{{4536, -3027}, {3972.29440307905, -3027}, {
         3617.28896959787, -2924.15472573989}, {
         3465.14378382022, -2880.07817962841}}], 
       BezierCurveBox[{{4834.6880030467, -3067.04307979686}, {
         4832.05551275464, -3027}, {4806.81665382639, -3027}, {4796, -3027}}],
        BezierCurveBox[{{4666, -3027}, {4666, -3027}, {4536, -3027}, {
        4536, -3027}}], 
       BezierCurveBox[{{4536, -3027}, {4486, -3027}, {
         4476.58283212345, -3045.8343357531}, {
         4472.5469030335, -3053.906193933}}]},
      "\"SUCCt2_2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "SUCCt2_2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4832, -1150}, {4785, -1150}, {4729, -1150}, {
        4705, -1150}}], 
       BezierCurveBox[{{4524.31638891101, -1314.8491141771}, {
         4843.29316685939, -1150}, {4746.48795005782, -1150}, {4705, -1150}}],
        BezierCurveBox[{{4705, -1150}, {4705, -1150}, {4665, -1150}, {
        4665, -1150}}], 
       BezierCurveBox[{{4625, -1150}, {4525, -1150}, {
         4494.58283212345, -1089.1656642469}, {
         4481.5469030335, -1063.093806067}}], 
       BezierCurveBox[{{4665, -1150}, {4665, -1150}, {4625, -1150}, {
        4625, -1150}}], 
       BezierCurveBox[{{4625, -1150}, {4520, -1150}, {4472.4, -1150}, {
         4452, -1150}}], 
       BezierCurveBox[{{4625, -1150}, {4412.75014723209, -1150}, {
         4303.07624685232, -1088.99307175931}, {
         4256.07314668957, -1062.84724537044}}], 
       BezierCurveBox[{{4254.16275689572, -1492.24391731472}, {
         5009.01480227121, -1150}, {4796.20444068136, -1150}, {4705, -1150}}]},
      "\"ATPS4r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ATPS4r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4185.17052179062, -1070.97099013199}, {
         4145, -1112.67875401714}, {4145, -1173.80362620514}, {4145, -1200}}],
        BezierCurveBox[{{4100.70693762787, -1093.95860190493}, {
         4145, -1123.67831238763}, {4145, -1177.10349371629}, {4145, -1200}}],
        BezierCurveBox[{{4145, -1200}, {4145, -1200}, {4145, -1260}, {
        4145, -1260}}], 
       BezierCurveBox[{{4145, -1260}, {4145, -1389.80754985747}, {
         4177.44245973031, -1445.51238876656}, {
         4191.3463710433, -1469.38589115617}}]},
      "\"ADK1\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ADK1", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{232, -3945}, {215, -3945}, {173, -3945}, {
        155, -3945}}], 
       BezierCurveBox[{{155, -3945}, {155, -3945}, {35, -3945}, {35, -3945}}]},
      "\"EX_pyr(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_pyr(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3257, -4614}, {3257, -4524}, {3257, -4493.9}, {
         3257, -4481}}], 
       BezierCurveBox[{{3257, -4711}, {3257, -4684}, {3257, -4635}, {
        3257, -4614}}]},
      "\"H2Ot\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "H2Ot", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2129.57136246402, -1299.6754148218}, {2100, -1340}, {
         2061.5, -1392.5}, {2045, -1415}}], 
       BezierCurveBox[{{2045, -1415}, {1994.12897414366, -1484.36958071319}, {
         1978.52536601188, -1506.80215546046}, {
         1971.83810538398, -1516.41611606644}}]},
      "\"RPE\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "RPE", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1582.43767677028, -1179.47267846876}, {
         1562.3991758304, -1265}, {1600.61975274912, -1265}, {1617, -1265}}], 
       BezierCurveBox[{{1617, -1265}, {1617, -1265}, {1637, -1265}, {
        1637, -1265}}], 
       BezierCurveBox[{{1657, -1265}, {1742, -1265}, {1768.6, -1265}, {
         1780, -1265}}], 
       BezierCurveBox[{{1637, -1265}, {1637, -1265}, {1657, -1265}, {
        1657, -1265}}], 
       BezierCurveBox[{{1537, -1265}, {1562, -1265}, {1600.5, -1265}, {
         1617, -1265}}], 
       BezierCurveBox[{{1657, -1265}, {1711.6008241696, -1265}, {
         1700.28845583337, -1216.71711861704}, {
         1695.44029797499, -1196.0244551672}}]},
      "\"PGL\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PGL", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2190, -3390}, {1624.97787653933, -3672.51106173033}, {
         1255.67579147629, -3849.06305997734}, {
         1097.40346930642, -3924.72820208319}}], 
       BezierCurveBox[{{2593.04871236642, -3202.8961240643}, {
         2462.16109883935, -3253.91945058032}, {
         2355.64832965181, -3307.1758351741}, {2310, -3330}}], 
       BezierCurveBox[{{2190, -3390}, {2140, -3415}, {2118.72, -3399.04}, {
         2109.6, -3392.2}}], 
       BezierCurveBox[{{2250, -3360}, {2250, -3360}, {2190, -3390}, {
        2190, -3390}}], 
       BezierCurveBox[{{2360.97184456747, -3239.97637399872}, {
         2364.03702434443, -3302.98148782779}, {
         2326.21110730333, -3321.89444634834}, {2310, -3330}}], 
       BezierCurveBox[{{2310, -3330}, {2310, -3330}, {2250, -3360}, {
        2250, -3360}}], 
       BezierCurveBox[{{2190, -3390}, {2130.33426443929, -3419.83286778035}, {
         2107.00020620872, -3419.88831547681}, {
         2096.99989553848, -3419.9120787753}}]},
      "\"ME1\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ME1", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1460, -4432}, {1460, -4621}, {1460, -4720.4}, {
         1460, -4763}}], 
       BezierCurveBox[{{1460, -4125}, {1460, -4263.5}, {1460, -4381.45}, {
         1460, -4432}}]},
      "\"FORti\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FORti", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3150.23533208728, -3483.05906886161}, {
         3067.96165706848, -3495.7929452157}, {
         3016.18849712054, -3460.23788356471}, {2994, -3445}}], 
       BezierCurveBox[{{2994, -3445}, {2994, -3445}, {2911, -3388}, {
        2911, -3388}}], 
       BezierCurveBox[{{3092.43430579858, -3417.55966995911}, {
         3043.06331388102, -3478.69408302673}, {
         3008.71899416431, -3455.10822490802}, {2994, -3445}}], 
       BezierCurveBox[{{2843, -3341}, {2767.27134484767, -3288.65813540942}, {
         2773.46419838851, -3229.95451337247}, {
         2776.11827847744, -3204.79581821378}}], 
       BezierCurveBox[{{2911, -3388}, {2911, -3388}, {2843, -3341}, {
        2843, -3341}}], 
       BezierCurveBox[{{2843, -3341}, {2733.02836867812, -3264.99019599811}, {
         2682.17397829194, -3231.85687480947}, {
         2660.379239555, -3217.65688001433}}], 
       BezierCurveBox[{{2843, -3341}, {2791.91589451253, -3305.69186826601}, {
         2829.70924227003, -3264.74074973967}, {
         2845.90639130896, -3247.19027037123}}], 
       BezierCurveBox[{{3154.93338231631, -3553.517746577}, {
         3086.36653060781, -3508.43243668247}, {
         3021.70995918234, -3464.02973100474}, {2994, -3445}}]},
      "\"MALS\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "MALS", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -4925}, {1055, -4925}, {1055, -5055}, {
        1055, -5055}}], 
       BezierCurveBox[{{1055, -4878}, {1055, -4880}, {1055, -4911.5}, {
         1055, -4925}}]},
      "\"EX_lac-D(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_lac-D(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{630, -1360}, {630, -1360}, {640, -1360}, {
        640, -1360}}], 
       BezierCurveBox[{{330, -1360}, {465, -1360}, {580.5, -1360}, {
         630, -1360}}], 
       BezierCurveBox[{{630, -1360}, {398.240426303464, -1360}, {
         826.30451341785, -1480.57967525381}, {
         1009.76055075259, -1532.25667893402}}], 
       BezierCurveBox[{{693.169133940685, -1439.19620679144}, {
         569.792027106039, -1360}, {611.937608131812, -1360}, {630, -1360}}], 
       BezierCurveBox[{{640, -1360}, {640, -1360}, {630, -1360}, {
        630, -1360}}], 
       BezierCurveBox[{{630, -1360}, {565.968757625672, -1360}, {
         645.515643842392, -1304.77108930993}, {
         679.607166506701, -1281.10155615704}}]},
      "\"FRUpts2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FRUpts2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1084.65053562438, -3379.56571321782}, {
         1207.82800864819, -3398.53309457802}, {
         1305.94840259446, -3440.15992837341}, {1348, -3458}}], 
       BezierCurveBox[{{1493, -3519}, {1552.83538696645, -3543.99452873282}, {
         1579.01371785461, -3514.94003109336}, {
         1590.23300252097, -3502.4881035336}}], 
       BezierCurveBox[{{1217.13768993058, -3360.89580080239}, {
         1264.10827573128, -3422.40957152236}, {
         1322.83248271939, -3447.32287145671}, {1348, -3458}}], 
       BezierCurveBox[{{1348, -3458}, {1348, -3458}, {1414, -3486}, {
        1414, -3486}}], 
       BezierCurveBox[{{1493, -3519}, {2039.20316086597, -3747.16081403262}, {
         2440.18389496214, -3732.17680697308}, {
         2612.03278100335, -3725.75508966185}}], 
       BezierCurveBox[{{1414, -3486}, {1414, -3486}, {1493, -3519}, {
        1493, -3519}}], 
       BezierCurveBox[{{1493, -3519}, {1572.3763206054, -3552.15719721491}, {
         1613.1750023578, -3535.79027383322}, {
         1630.66015168025, -3528.7758780982}}], 
       BezierCurveBox[{{1297.38871282068, -3394.85683889899}, {
         1302.67127846377, -3438.76963328766}, {
         1334.40138353913, -3452.2308899863}, {1348, -3458}}]},
      "\"PPC\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PPC", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{337.847646670391, -4012.78441616471}, {
         322.798467455447, -3945}, {359.339540236634, -3945}, {375, -3945}}], 
       BezierCurveBox[{{505, -3945}, {505, -3945}, {645, -3945}, {
        645, -3945}}], 
       BezierCurveBox[{{645, -3945}, {697.201532544553, -3945}, {
         687.27397343721, -3989.71564783837}, {
         683.019305248349, -4008.87949691195}}], 
       BezierCurveBox[{{375, -3945}, {375, -3945}, {505, -3945}, {
        505, -3945}}], 
       BezierCurveBox[{{318, -3945}, {325, -3945}, {360, -3945}, {
        375, -3945}}], 
       BezierCurveBox[{{645, -3945}, {850, -3945}, {960.6, -3945}, {
         1008, -3945}}]},
      "\"PYRt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PYRt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2684, -3076}, {2642.88565263456, -3127.63197111009}, {
         2638.15652249502, -3141.54084513495}, {
         2636.12975243522, -3147.50179114561}}], 
       BezierCurveBox[{{2727, -3022}, {2727, -3022}, {2684, -3076}, {
        2684, -3076}}], 
       BezierCurveBox[{{2734.16709398566, -2947.86303237062}, {
         2758.6790576998, -2982.21699730723}, {
         2736.50371730994, -3010.06509919217}, {2727, -3022}}], 
       BezierCurveBox[{{2806.33148223852, -2942.45929217888}, {
         2775.11076106793, -2961.58183493795}, {
         2741.43322832038, -3003.87455048139}, {2727, -3022}}]},
      "\"FUM\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FUM", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1063, -545}, {1063, -545}, {1063, -405}, {
        1063, -405}}], 
       BezierCurveBox[{{1063, -662}, {1063, -625}, {1063, -569}, {
        1063, -545}}]},
      "\"EX_glc(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_glc(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3621, -4914}, {3621, -4914}, {3621, -5054}, {
        3621, -5054}}], 
       BezierCurveBox[{{3621, -4797}, {3621, -4834}, {3621, -4890}, {
        3621, -4914}}]},
      "\"EX_co2(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_co2(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2342, -4071}, {2295.50087478155, -4021.17950869452}, {
         2311.41635609454, -3984.60296584986}, {
         2318.23727665725, -3968.92730463072}}], 
       BezierCurveBox[{{2342, -4071}, {2306.5769040813, -4033.04668294425}, {
         2344.3703287459, -4009.57743503185}, {
         2360.56751074501, -3999.51918592654}}], 
       BezierCurveBox[{{2471.17591008932, -4197.02382107167}, {
         2437.68650734056, -4162.24074018452}, {
         2391.00595220217, -4118.67222205536}, {2371, -4100}}], 
       BezierCurveBox[{{2459.70530022369, -4089.32994783973}, {
         2413.54276875565, -4139.70658417194}, {
         2383.76283062669, -4111.91197525158}, {2371, -4100}}], 
       BezierCurveBox[{{2371, -4100}, {2371, -4100}, {2356, -4086}, {
        2356, -4086}}], 
       BezierCurveBox[{{2342, -4071}, {2279.74430169457, -4004.29746610133}, {
         2255.98846743603, -3984.09996261461}, {
         2245.80739561093, -3975.44388969173}}], 
       BezierCurveBox[{{2356, -4086}, {2356, -4086}, {2342, -4071}, {
        2342, -4071}}]},
      "\"ALCD2x\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ALCD2x", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{5015, -3636}, {5015, -3636}, {5106, -3636}, {
        5106, -3636}}], 
       BezierCurveBox[{{4925.98026617663, -3635.30258181562}, {
         4948.99242467716, -3636}, {4995.19772740315, -3636}, {5015, -3636}}]},
      "\"EX_glu-L(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_glu-L(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2840, -470}, {2840, -470}, {2840, -400}, {
        2840, -400}}], 
       BezierCurveBox[{{2840, -607}, {2840, -560}, {2840, -497}, {
        2840, -470}}]},
      "\"EX_fum(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_fum(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2880, -4914}, {2880, -4914}, {2880, -5054}, {
        2880, -5054}}], 
       BezierCurveBox[{{2880, -4876.5}, {2880, -4882}, {2880, -4902.75}, {
         2880, -4914}}]},
      "\"EX_pi(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_pi(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4421.70435964516, -3763.07895686375}, {
         4364, -3788.55994705495}, {4364, -3830.86798411649}, {4364, -3849}}],
        BezierCurveBox[{{4364, -3869}, {4364, -3869}, {4364, -3889}, {
        4364, -3889}}], 
       BezierCurveBox[{{4364, -3889}, {4364, -3936.76243293636}, {
         4387.85128156301, -3942.63583387202}, {
         4398.07325937573, -3945.15300570159}}], 
       BezierCurveBox[{{4364, -3889}, {4364, -4007.26770480567}, {
         4307.90939294463, -4048.49539199851}, {
         4283.87056134946, -4066.16440079545}}], 
       BezierCurveBox[{{4420.0000143379, -3805.02394819331}, {
         4364, -3805.0910031998}, {4364, -3835.82730095994}, {4364, -3849}}], 
       BezierCurveBox[{{4364, -3889}, {4364, -3978.61724164467}, {
         4395.37608339584, -4012.40603754132}, {
         4408.82297627977, -4026.88695006845}}], 
       BezierCurveBox[{{4271.31088115481, -3650.88393019967}, {
         4364, -3725.97053198522}, {4364, -3812.09115959557}, {4364, -3849}}],
        BezierCurveBox[{{4364, -3889}, {4364, -3956.31456008918}, {
         4391.59475962979, -3975.11267797746}, {
         4403.42108518541, -3983.1690142153}}], 
       BezierCurveBox[{{4364, -3849}, {4364, -3849}, {4364, -3869}, {
        4364, -3869}}]},
      "\"GLNS\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "GLNS", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4970, -1660}, {4970, -1660}, {5110, -1660}, {
        5110, -1660}}], 
       BezierCurveBox[{{4893, -1660}, {4910, -1660}, {4952, -1660}, {
        4970, -1660}}]},
      "\"EX_o2(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_o2(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2305, -1425}, {2232.69957479275, -1342.55214669349}, {
         2201.59576651624, -1311.50735515351}, {
         2188.26556296916, -1298.20244449351}}], 
       BezierCurveBox[{{2390.64910559069, -1522.67003269114}, {2362, -1490}, {
         2322.1, -1444.5}, {2305, -1425}}]},
      "\"RPI\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "RPI", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -2995}, {1055, -2935}, {1055, -2925.9}, {
         1055, -2922}}], 
       BezierCurveBox[{{1055, -3082}, {1055, -3060}, {1055, -3014.5}, {
         1055, -2995}}]},
      "\"PGM\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PGM", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1555, -3945}, {1635, -3945}, {1658.1, -3945}, {
         1668, -3945}}], 
       BezierCurveBox[{{1555, -3945}, {1613.30951894845, -3945}, {
         1627.71390935671, -3924.26952621567}, {
         1633.88721953167, -3915.38503745096}}], 
       BezierCurveBox[{{1367.09747864011, -3874.88971048945}, {
         1374.49099172206, -3945}, {1413.34729751662, -3945}, {1430, -3945}}],
        BezierCurveBox[{{1555, -3945}, {1606.47815070493, -3945}, {
         1605.86876677638, -3907.89650751678}, {
         1605.60760223558, -3891.99501073825}}], 
       BezierCurveBox[{{1430, -3945}, {1430, -3945}, {1495, -3945}, {
        1495, -3945}}], 
       BezierCurveBox[{{1331.0838771422, -3916.88734184226}, {
         1369.12102169057, -3945}, {1411.73630650717, -3945}, {1430, -3945}}],
        BezierCurveBox[{{1085, -3945}, {1242.5, -3945}, {1373.75, -3945}, {
         1430, -3945}}], 
       BezierCurveBox[{{1495, -3945}, {1495, -3945}, {1555, -3945}, {
        1555, -3945}}]},
      "\"PDH\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PDH", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2500, -4430}, {2500, -4328.99876238382}, {
         2500.37426939979, -4291.19801620718}, {
         2500.53467057112, -4274.99769641719}}], 
       BezierCurveBox[{{2567.78441616471, -4767.15235332961}, {
         2500, -4782.20153254455}, {2500, -4745.66045976337}, {2500, -4730}}],
        BezierCurveBox[{{2500, -4787}, {2500, -4780}, {2500, -4745}, {
        2500, -4730}}], 
       BezierCurveBox[{{2500, -4730}, {2500, -4730}, {2500, -4550}, {
        2500, -4550}}], 
       BezierCurveBox[{{2500, -4430}, {2500, -4377.79846745545}, {
         2544.71564783837, -4387.72602656279}, {
         2563.87949691195, -4391.98069475165}}], 
       BezierCurveBox[{{2500, -4550}, {2500, -4550}, {2500, -4430}, {
        2500, -4430}}]},
      "\"ETOHt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ETOHt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2610, -470}, {2610, -470}, {2610, -400}, {
        2610, -400}}], 
       BezierCurveBox[{{2610, -607}, {2610, -560}, {2610, -497}, {
        2610, -470}}]},
      "\"EX_mal-L(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_mal-L(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1249.47216667095, -1192.12991947345}, {
         1232.3991758304, -1265}, {1270.61975274912, -1265}, {1287, -1265}}], 
       BezierCurveBox[{{1287, -1265}, {1287, -1265}, {1307, -1265}, {
        1307, -1265}}], 
       BezierCurveBox[{{1327, -1265}, {1393.00189391222, -1265}, {
         1399.37798280341, -1217.17286328759}, {
         1402.11059232821, -1196.67551898227}}], 
       BezierCurveBox[{{1098, -1265}, {1171, -1265}, {1252.2, -1265}, {
         1287, -1265}}], 
       BezierCurveBox[{{1327, -1265}, {1381.6008241696, -1265}, {
         1370.28845583337, -1216.71711861704}, {
         1365.44029797499, -1196.0244551672}}], 
       BezierCurveBox[{{1327, -1265}, {1417, -1265}, {1447.1, -1265}, {
         1460, -1265}}], 
       BezierCurveBox[{{1307, -1265}, {1307, -1265}, {1327, -1265}, {
        1327, -1265}}]},
      "\"G6PDH2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "G6PDH2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2880, -4725}, {2880, -4725}, {2880, -4580}, {
        2880, -4580}}], 
       BezierCurveBox[{{2880, -4520}, {2880, -4464.78904094294}, {
         2844.72461680218, -4459.60354301197}, {
         2829.60659543168, -4457.38118675583}}], 
       BezierCurveBox[{{2880, -4796}, {2880, -4782}, {2880, -4742.1}, {
         2880, -4725}}], 
       BezierCurveBox[{{2880, -4520}, {2880, -4475}, {2880, -4477}, {
         2880, -4476.4}}], 
       BezierCurveBox[{{2880, -4580}, {2880, -4580}, {2880, -4520}, {
        2880, -4520}}], 
       BezierCurveBox[{{2825.9907192551, -4777.2174126049}, {
         2880, -4775.93623464686}, {2880, -4740.28087039406}, {2880, -4725}}]},
      "\"PIt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PIt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{182, -1360}, {182, -1360}, {44, -1360}, {44, -1360}}],
        BezierCurveBox[{{257, -1360}, {241, -1360}, {199.7, -1360}, {
         182, -1360}}]},
      "\"EX_fru(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_fru(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4975, -2880}, {4978.5, -2880}, {5011.05, -2880}, {
         5025, -2880}}], 
       BezierCurveBox[{{5025, -2880}, {5025, -2880}, {5115, -2880}, {
        5115, -2880}}]},
      "\"EX_succ(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_succ(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1715, -4255}, {1715, -4215}, {1715, -4222}, {
         1715, -4219.9}}], 
       BezierCurveBox[{{1715, -4305}, {1715, -4305}, {1715, -4275}, {
        1715, -4275}}], 
       BezierCurveBox[{{1715, -4275}, {1715, -4275}, {1715, -4255}, {
        1715, -4255}}], 
       BezierCurveBox[{{1715, -4345}, {1715, -4342}, {1715, -4317}, {
        1715, -4305}}], 
       BezierCurveBox[{{1782.78441616471, -4342.15235332961}, {
         1715, -4357.20153254455}, {1715, -4320.66045976337}, {1715, -4305}}],
        BezierCurveBox[{{1715, -4255}, {1715, -4202.79846745545}, {
         1759.71564783837, -4212.72602656279}, {
         1778.87949691195, -4216.98069475165}}]},
      "\"ACKr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACKr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1987.55125860631, -1548.80400201593}, {
         2175, -1521.50910964772}, {2175, -1607.95273289431}, {2175, -1645}}],
        BezierCurveBox[{{2376.56737169658, -1548.03781246564}, {
         2175, -1514.96538922271}, {2175, -1605.98961676681}, {2175, -1645}}],
        BezierCurveBox[{{2175, -1735}, {2175, -1867.09844813623}, {
         2046.89863075994, -1865.92969126871}, {
         1991.99804394277, -1865.42879546834}}], 
       BezierCurveBox[{{2175, -1695}, {2175, -1695}, {2175, -1735}, {
        2175, -1735}}], 
       BezierCurveBox[{{2175, -1735}, {2175, -1867.09844813623}, {
         2303.10136924006, -1865.92969126871}, {
         2358.00195605723, -1865.42879546834}}], 
       BezierCurveBox[{{2175, -1645}, {2175, -1645}, {2175, -1695}, {
        2175, -1695}}]},
      "\"TKT1\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "TKT1", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1987.52340342619, -1858.6156315071}, {
         2165.76412270224, -1831.85496936319}, {
         2172.22923681067, -1918.05649080896}, {2175, -1955}}], 
       BezierCurveBox[{{2178, -1995}, {2178, -1995}, {2178, -2035}, {
        2178, -2035}}], 
       BezierCurveBox[{{2178, -2035}, {2178, -2174.92319321685}, {
         2047.73133876619, -2183.35252984913}, {
         1991.90191252313, -2186.96510269154}}], 
       BezierCurveBox[{{2362.40684115223, -1859.0989137128}, {
         2165.76412270224, -1831.85496936319}, {
         2172.22923681067, -1918.05649080896}, {2175, -1955}}], 
       BezierCurveBox[{{2175, -1955}, {2175, -1955}, {2178, -1995}, {
        2178, -1995}}], 
       BezierCurveBox[{{2178, -2035}, {2178, -2176.59272580186}, {
         2311.05251813919, -2184.11961016239}, {
         2368.07502591312, -2187.34541774547}}]},
      "\"TALA\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "TALA", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4925, -4158}, {4951, -4158}, {4999.3, -4158}, {
         5020, -4158}}], 
       BezierCurveBox[{{5020, -4158}, {5020, -4158}, {5107, -4158}, {
        5107, -4158}}]},
      "\"EX_gln-L(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_gln-L(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2840, -980}, {2840, -1032.20153254455}, {
         2884.71564783837, -1022.27397343721}, {
         2903.87949691195, -1018.01930524835}}], 
       BezierCurveBox[{{2840, -680}, {2840, -690}, {2840, -718}, {
        2840, -730}}], 
       BezierCurveBox[{{2840, -730}, {2840, -730}, {2840, -840}, {
        2840, -840}}], 
       BezierCurveBox[{{2840, -840}, {2840, -840}, {2840, -980}, {
        2840, -980}}], 
       BezierCurveBox[{{2920.47540373619, -695.665240406298}, {
         2840, -677.798467455447}, {2840, -714.339540236634}, {2840, -730}}], 
       BezierCurveBox[{{2840, -980}, {2840, -1950.00115979312}, {
         2841.99824778766, -2596.10050528653}, {
         2842.85463969666, -2873.00022478371}}]},
      "\"FUMt2_2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FUMt2_2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4215, -1350}, {4215, -1430}, {4215, -1453.1}, {
         4215, -1463}}], 
       BezierCurveBox[{{4215, -1070}, {4215, -1120}, {4215, -1176}, {
        4215, -1200}}], 
       BezierCurveBox[{{4215, -1350}, {4215, -1388.07886552932}, {
         4238.27078986914, -1385.39312864198}, {
         4248.24398552734, -1384.2420985474}}], 
       BezierCurveBox[{{4215, -1260}, {4215, -1260}, {4215, -1350}, {
        4215, -1350}}], 
       BezierCurveBox[{{4255.80634035479, -1145.6216927543}, {
         4215, -1157.57359312881}, {4215, -1187.27207793864}, {4215, -1200}}],
        BezierCurveBox[{{4215, -1200}, {4215, -1200}, {4215, -1260}, {
        4215, -1260}}], 
       BezierCurveBox[{{4215, -1350}, {4215, -1411.03277807867}, {
         4241.37008551134, -1425.71233485302}, {
         4252.67155073048, -1432.0035734706}}]},
      "\"ATPM\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ATPM", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{3470, -1270}, {3400, -1270}, {3383.9, -1270}, {
         3377, -1270}}], 
       BezierCurveBox[{{3608.88039979688, -1148.65551429389}, {
         3646.48529270389, -1270}, {3592.94558781117, -1270}, {3570, -1270}}],
        BezierCurveBox[{{3470, -1270}, {3390.94305849579, -1270}, {
         3405.02607372478, -1197.29956509556}, {
         3411.06165168006, -1166.14223585081}}], 
       BezierCurveBox[{{3570, -1270}, {3570, -1270}, {3520, -1270}, {
        3520, -1270}}], 
       BezierCurveBox[{{3710, -1270}, {3655, -1270}, {3595.5, -1270}, {
         3570, -1270}}], 
       BezierCurveBox[{{3520, -1270}, {3520, -1270}, {3470, -1270}, {
        3470, -1270}}]},
      "\"NADTRHD\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "NADTRHD", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2610, -736}, {2610, -736}, {2610, -756}, {
        2610, -756}}], 
       BezierCurveBox[{{2610, -980}, {2610, -2086.01367532233}, {
         2617.3727969473, -2827.30572971653}, {
         2620.53256706757, -3145.00232445691}}], 
       BezierCurveBox[{{2610, -980}, {2610, -1032.20153254455}, {
         2565.28435216163, -1022.27397343721}, {
         2546.12050308805, -1018.01930524835}}], 
       BezierCurveBox[{{2529.712495522, -696.621017861059}, {
         2610, -682.858678977654}, {2610, -720.057603693296}, {2610, -736}}], 
       BezierCurveBox[{{2610, -680}, {2610, -693}, {2610, -723.1}, {
         2610, -736}}], 
       BezierCurveBox[{{2610, -756}, {2610, -756}, {2610, -980}, {
        2610, -980}}]},
      "\"MALt2_2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "MALt2_2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2210, -4570}, {2210, -4257.5}, {2210, -4071.65}, {
         2210, -3992}}], 
       BezierCurveBox[{{2210, -4801}, {2210, -4707}, {2210, -4611.1}, {
         2210, -4570}}]},
      "\"ACALDt\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACALDt", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4662, -3228}, {4662, -3228}, {4502, -3228}, {
        4502, -3228}}], 
       BezierCurveBox[{{4837.18641513903, -3288.15419724589}, {
         4843.02205405508, -3228}, {4807.30661621653, -3228}, {4792, -3228}}],
        BezierCurveBox[{{4792, -3228}, {4792, -3228}, {4662, -3228}, {
        4662, -3228}}], 
       BezierCurveBox[{{4502, -3228}, {4449.79846745545, -3228}, {
         4459.72602656279, -3272.71564783837}, {
         4463.98069475165, -3291.87949691195}}], 
       BezierCurveBox[{{4879, -3228}, {4857, -3228}, {4811.5, -3228}, {
         4792, -3228}}], 
       BezierCurveBox[{{4502, -3228}, {4074.584218822, -3228}, {
         3865.48988192882, -3481.90336979504}, {
         3775.87802326032, -3590.7190997072}}]},
      "\"AKGt2r\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "AKGt2r", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{4770, -2846}, {4852.76472678623, -2846}, {
         4877.99535568787, -2856.8265087992}, {
         4888.80848236, -2861.46644114171}}], 
       BezierCurveBox[{{4667, -2846}, {4667, -2846}, {4770, -2846}, {
        4770, -2846}}], 
       BezierCurveBox[{{3449.97965369646, -2865.89529902671}, {
         3989.90329767661, -2846}, {4388.97098930298, -2846}, {4560, -2846}}],
        BezierCurveBox[{{4560, -2846}, {4560, -2846}, {4667, -2846}, {
        4667, -2846}}], 
       BezierCurveBox[{{4783.49231546411, -2925.58975691733}, {
         4431.4455368336, -2846}, {4521.43366105008, -2846}, {4560, -2846}}], 
       BezierCurveBox[{{4770, -2846}, {4914.10065926289, -2846}, {
         4644.12031545271, -2797.38954256692}, {
         4528.41445381978, -2776.55648938131}}]},
      "\"SUCCt3\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "SUCCt3", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1055, -3405}, {1055, -3515}, {1055, -3613}, {
        1055, -3655}}], 
       BezierCurveBox[{{1055, -3745}, {1055, -3802.00877125496}, {
         1017.63431781278, -3807.40239486061}, {
         1001.62045401826, -3809.71394783446}}], 
       BezierCurveBox[{{1055, -3705}, {1055, -3705}, {1055, -3745}, {
        1055, -3745}}], 
       BezierCurveBox[{{983.795559444788, -3561.83571102062}, {
         1055, -3587.73187976463}, {1055, -3634.81956392939}, {1055, -3655}}],
        BezierCurveBox[{{1055, -3655}, {1055, -3655}, {1055, -3705}, {
        1055, -3705}}], 
       BezierCurveBox[{{984.634993979067, -3621.19644752343}, {
         1055, -3607.56583509747}, {1055, -3640.76975052924}, {1055, -3655}}],
        BezierCurveBox[{{1055, -3745}, {1055, -3845}, {1055, -3882.1}, {
         1055, -3898}}]},
      "\"PYK\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "PYK", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{783.091387130783, -1846.47347012647}, {
         835, -1822.00877125496}, {835, -1782.10263137649}, {835, -1765}}], 
       BezierCurveBox[{{835, -1665}, {835, -1600.96875762567}, {
         802.622217987378, -1586.41140020481}, {
         788.746025696254, -1580.17253273873}}], 
       BezierCurveBox[{{835, -1765}, {835, -1765}, {835, -1715}, {
        835, -1715}}], 
       BezierCurveBox[{{835, -1715}, {835, -1715}, {835, -1665}, {
        835, -1665}}], 
       BezierCurveBox[{{835, -1665}, {835, -1539.70035913858}, {
         956.109541671424, -1542.61780039199}, {
         1008.01363095918, -1543.86813235773}}], 
       BezierCurveBox[{{1025.17671985963, -1921.74854468441}, {
         835, -1901.01470508735}, {835, -1805.80441152621}, {835, -1765}}]},
      "\"FBP\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FBP", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{2167, -3945}, {2125, -3945}, {2065.5, -3945}, {
         2040, -3945}}], 
       BezierCurveBox[{{2075.76063945801, -3892.49330751147}, {
         2085.0693909433, -3945}, {2053.52081728299, -3945}, {2040, -3945}}], 
       BezierCurveBox[{{1980, -3945}, {1847.5, -3945}, {1787.65, -3945}, {
         1762, -3945}}], 
       BezierCurveBox[{{1980, -3945}, {1918.1029079843, -3945}, {
         1906.56115048239, -3910.09082304898}, {
         1901.61468298158, -3895.12974721283}}], 
       BezierCurveBox[{{2119.64095842184, -3891.33193670334}, {
         2101.8970920157, -3945}, {2058.56912760471, -3945}, {2040, -3945}}], 
       BezierCurveBox[{{2010, -3945}, {2010, -3945}, {1980, -3945}, {
        1980, -3945}}], 
       BezierCurveBox[{{2040, -3945}, {2040, -3945}, {2010, -3945}, {
        2010, -3945}}], 
       BezierCurveBox[{{1980, -3945}, {1934.9306090567, -3945}, {
         1940.95795356663, -3911.00232316809}, {
         1943.54110121374, -3896.43189024013}}]},
      "\"ACALD\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ACALD", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{5032, -3228}, {5032, -3228}, {5112, -3228}, {
        5112, -3228}}], 
       BezierCurveBox[{{4965, -3228}, {4977, -3228}, {5015.5, -3228}, {
         5032, -3228}}]},
      "\"EX_akg(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_akg(e)", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0.5], Thickness[0.0018358590828577053`], 
       BezierCurveBox[{{1715, -4888}, {1715, -4890}, {1715, -4921.5}, {
         1715, -4935}}], 
       BezierCurveBox[{{1715, -4935}, {1715, -4935}, {1715, -5055}, {
        1715, -5055}}]},
      "\"EX_ac(e)\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "EX_ac(e)", "Tooltip"]& ]}, {
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1715, -3945}, 25]},
      "\"accoa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "accoa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2265}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4850, -1660}, 25]},
      "\"o2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "o2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4400, -1900}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2415, -2190}, 25]},
      "\"f6p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "f6p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4922, -3228}, 25]},
      "\"akg\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "akg", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4335}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2057, -1165}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2500, -4830}, 25]},
      "\"etoh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "etoh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{945, -1095}, 15]},
      "\"pep\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pep", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4415, -1150}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3495, -4065}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4495, -1330}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{735, -3475}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4215, -1510}, 25]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{710, -1450}, 15]},
      "\"pep\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pep", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3989, -4757}, 25]},
      "\"nh4\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nh4", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1285, -3545}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4285, -4258}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2940, -700}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1357, -1160}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2843, -2920}, 25]},
      "\"fum\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "fum", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4803, -2930}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1270, -4440}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{735, -3855}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3170, -3480}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4035}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4135}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4142, -3558}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3420, -2867}, 25]},
      "\"succ\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "succ", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2130, -3860}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3180, -3970}, 25]},
      "\"acon-C\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "acon-C", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2200, -3540}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -2565}, 25]},
      "\"13dpg\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "13dpg", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4310, -2570}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{965, -3555}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3510, -650}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -1265}, 25]},
      "\"g6p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "g6p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2793, -4452}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -2195}, 25]},
      "\"g3p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "g3p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -1855}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4434, -4054}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2680, -3585}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4275, -1140}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2515}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1687, -1160}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1315, -3905}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -2875}, 25]},
      "\"3pg\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "3pg", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4335, -4258}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2007, -1165}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -3375}, 25]},
      "\"pep\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pep", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2392, -3980}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{955, -4255}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4201, -3940}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{765, -1855}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3684, -3506}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4246, -4094}, 25]},
      "\"gln-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "gln-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2315}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4192, -3558}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{735, -3525}, 15]},
      "\"amp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "amp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3257, -4434}, 25]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3105, -3402}, 15]},
      "\"accoa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "accoa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3180, -3570}, 25]},
      "\"glx\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "glx", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1945, -1555}, 25]},
      "\"xu5p-D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "xu5p-D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1215, -3515}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2660, -3510}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1507, -1265}, 25]},
      "\"6pgl\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "6pgl", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4836, -3087}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1063, -705}, 25]},
      "\"glc-D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "glc-D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4535, -4258}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2780, -3168}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4248, -3632}, 25]},
      "\"glu-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "glu-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4492, -2770}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2793, -4778}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2715, -2921}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3820, -3233}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4043, -3759}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3413, -3976}, 25]},
      "\"icit\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "icit", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3659, -3660}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3684, -3558}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2210, -3945}, 25]},
      "\"acald\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "acald", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1907, -1165}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3500, -3030}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4435}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2210, -4844}, 25]},
      "\"acald\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "acald", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4420, -2480}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -1545}, 25]},
      "\"f6p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "f6p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2600, -4400}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3020, -2740}, 15]},
      "\"q8h2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "q8h2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3942, -3558}, 15]},
      "\"nh4\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nh4", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{675, -4045}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1407, -1160}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{735, -3805}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2897, -4117}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1945, -1865}, 25]},
      "\"s7p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "s7p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3330, -1270}, 25]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1605, -3855}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{965, -3815}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1365, -3855}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2430, -3370}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2871, -3220}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4510, -1740}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2610, -3860}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4775}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3180, -4100}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2880, -4430}, 25]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{955, -4095}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3621, -4754}, 25]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -3125}, 25]},
      "\"2pg\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "2pg", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -4835}, 25]},
      "\"lac-D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "lac-D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2080, -3370}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4434, -4004}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3992, -3558}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4330, -1660}, 25]},
      "\"o2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "o2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1715, -4385}, 25]},
      "\"ac\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ac", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1295, -3375}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3989, -4441}, 25]},
      "\"nh4\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nh4", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4042, -3558}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1950, -3860}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2155, -1265}, 25]},
      "\"ru5p-D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ru5p-D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2070, -3860}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1945, -2190}, 25]},
      "\"e4p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "e4p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{965, -3625}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4065, -1070}, 25]},
      "\"amp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "amp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4865, -1150}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1505, -3625}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2510, -1010}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2805}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3510, -1040}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1715, -4845}, 25]},
      "\"ac\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "ac", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -3945}, 25]},
      "\"pyr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pyr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4465, -1030}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2840, -650}, 25]},
      "\"fum\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "fum", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2806, -4091}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1165, -4045}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4193, -3762}, 15]},
      "\"nh4\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nh4", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4478, -3688}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -1645}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4610, -2220}, 25]},
      "\"q8h2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "q8h2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4285, -1450}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4834, -3321}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{955, -4765}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4860, -1900}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1155, -1095}, 15]},
      "\"pyr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pyr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4472, -3328}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1827, -1265}, 25]},
      "\"6pgc\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "6pgc", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3739, -3193}, 25]},
      "\"succoa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "succoa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1715, -4175}, 25]},
      "\"actp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "actp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4883, -3634}, 25]},
      "\"glu-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "glu-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4720, -2070}, 25]},
      "\"q8\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "q8", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2635}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1270, -4770}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3621, -4434}, 25]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2621, -3192}, 25]},
      "\"mal-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "mal-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4029, -3932}, 15]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2360, -3220}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -1805}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -1925}, 25]},
      "\"fdp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "fdp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1890, -3860}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4215, -1040}, 25]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4440, -3755}, 15]},
      "\"atp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "atp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1205, -3345}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2060, -3420}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1587, -1160}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4385, -4258}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4434, -3954}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3620, -3710}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2610, -650}, 25]},
      "\"mal-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "mal-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1460, -4810}, 25]},
      "\"for\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "for", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4932, -2880}, 25]},
      "\"succ\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "succ", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2659, -3724}, 25]},
      "\"oaa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "oaa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4825, -3703}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2600, -4760}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{300, -1360}, 25]},
      "\"fru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "fru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3740, -1270}, 25]},
      "\"nadph\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadph", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3460, -2960}, 15]},
      "\"coa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "coa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4029, -3982}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2880, -4839}, 25]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{955, -4415}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4485, -4258}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3600, -1120}, 25]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4440, -3805}, 15]},
      "\"nh4\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nh4", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{735, -3425}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1055, -4345}, 25]},
      "\"lac-D\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "lac-D", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{755, -1565}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3257, -4754}, 25]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1815, -4225}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4285, -1380}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{710, -1260}, 15]},
      "\"pyr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pyr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{275, -3945}, 25]},
      "\"pyr\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pyr", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1257, -1160}, 15]},
      "\"nadp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1145, -2465}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1460, -4095}, 25]},
      "\"for\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "for", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3794, -3051}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2333, -3935}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4882, -4158}, 25]},
      "\"gln-L\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "gln-L", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2670, -3310}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4850, -2570}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2405, -1865}, 25]},
      "\"g3p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "g3p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3768, -3116}, 15]},
      "\"adp\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "adp", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1665, -3515}, 15]},
      "\"pi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "pi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3746, -3627}, 25]},
      "\"akg\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "akg", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2260, -3510}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3872, -3285}, 15]},
      "\"co2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "co2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4850, -2229}, 25]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2510, -700}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2940, -1010}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{855, -2195}, 25]},
      "\"dhap\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "dhap", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{965, -3325}, 15]},
      "\"h2o\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h2o", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2971, -3986}, 25]},
      "\"cit\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "cit", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2419, -1555}, 25]},
      "\"r5p\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "r5p", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2482, -4065}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1655, -3885}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4420, -2650}, 15]},
      "\"nad\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nad", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{1615, -3475}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{4456, -3087}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{955, -4045}, 15]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{345, -4045}, 15]},
      "\"h\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "h", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3210, -2730}, 15]},
      "\"q8\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "q8", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{2501, -4228}, 25]},
      "\"etoh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "etoh", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
       PointSize[0.00900794502898862], DiskBox[{3420, -1120}, 25]},
      "\"nadh\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "nadh", "Tooltip"]& ]}, 
   StyleBox[{InsetBox["\<\"accoa\"\>", {1695, -3965}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {1165, -2265}, {-1, 0}], 
     InsetBox["\<\"o2[e]\"\>", {4850, -1690}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4400, -1920}, {-1, 0}], 
     InsetBox["\<\"f6p\"\>", {2420, -2220}, {-1, 0}], 
     InsetBox["\<\"akg[e]\"\>", {4922, -3268}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {1835, -4335}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {2080, -1140}, {-1, 0}], 
     InsetBox["\<\"etoh[e]\"\>", {2530, -4830}, {-1, 0}], 
     InsetBox["\<\"pep\"\>", {935, -1115}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4415, -1170}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {3495, -4098}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {4495, -1350}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {715, -3475}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {4195, -1540}, {-1, 0}], 
     InsetBox["\<\"pep\"\>", {710, -1470}, {-1, 0}], 
     InsetBox["\<\"nh4[e]\"\>", {4019, -4757}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {1285, -3575}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {4285, -4278}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {2940, -720}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1357, -1140}, {-1, 0}], 
     InsetBox["\<\"fum\"\>", {2818, -2892}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4830, -2930}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1250, -4440}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {715, -3855}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {3190, -3480}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {1835, -4035}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {1835, -4135}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {4142, -3528}, {-1, 0}], 
     InsetBox["\<\"succ\"\>", {3393, -2888}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {2140, -3840}, {-1, 0}], 
     InsetBox["\<\"acon-C\"\>", {3180, -3940}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {2220, -3550}, {-1, 0}], 
     InsetBox["\<\"13dpg\"\>", {1085, -2565}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4309, -2595}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {945, -3555}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {3510, -630}, {-1, 0}], 
     InsetBox["\<\"g6p\"\>", {1075, -1245}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2770, -4452}, {-1, 0}], 
     InsetBox["\<\"g3p\"\>", {1085, -2195}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1165, -1855}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {4454, -4054}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {2710, -3590}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4295, -1140}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {1165, -2515}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1687, -1140}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {1295, -3905}, {-1, 0}], 
     InsetBox["\<\"3pg\"\>", {1085, -2875}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4335, -4278}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {2007, -1145}, {-1, 0}], 
     InsetBox["\<\"pep\"\>", {1085, -3355}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2406, -3965}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {935, -4255}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4200, -3960}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {738, -1855}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {3658, -3504}, {-1, 0}], 
     InsetBox["\<\"gln-L\"\>", {4245, -4130}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {1165, -2315}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4210, -3530}, {-1, 0}], 
     InsetBox["\<\"amp\"\>", {715, -3525}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {3287, -4434}, {-1, 0}], 
     InsetBox["\<\"accoa\"\>", {3125, -3402}, {-1, 0}], 
     InsetBox["\<\"glx\"\>", {3150, -3570}, {-1, 0}], 
     InsetBox["\<\"xu5p-D\"\>", {1940, -1590}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {1215, -3535}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2692, -3510}, {-1, 0}], 
     InsetBox["\<\"6pgl\"\>", {1507, -1235}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4836, -3115}, {-1, 0}], 
     InsetBox["\<\"glc-D[e]\"\>", {1093, -705}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {4535, -4278}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {2800, -3168}, {-1, 0}], 
     InsetBox["\<\"glu-L\"\>", {4247, -3601}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4470, -2772}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {2810, -4794}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {2695, -2911}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {3846, -3233}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {4016, -3762}, {-1, 0}], 
     InsetBox["\<\"icit\"\>", {3383, -3946}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {3635, -3657}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {3661, -3556}, {-1, 0}], 
     InsetBox["\<\"acald\"\>", {2210, -3905}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {1907, -1145}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {3500, -3050}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1835, -4435}, {-1, 0}], 
     InsetBox["\<\"acald[e]\"\>", {2240, -4844}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {4400, -2480}, {-1, 0}], 
     InsetBox["\<\"f6p\"\>", {1075, -1525}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2620, -4400}, {-1, 0}], 
     InsetBox["\<\"q8h2\"\>", {3040, -2740}, {-1, 0}], 
     InsetBox["\<\"nh4\"\>", {3910, -3570}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {675, -4065}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {1430, -1140}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {715, -3805}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2880, -4140}, {-1, 0}], 
     InsetBox["\<\"s7p\"\>", {1940, -1900}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {3330, -1310}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {1595, -3835}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {945, -3815}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {1345, -3855}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {2450, -3370}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2891, -3220}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4485, -1740}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {2590, -3860}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {1835, -4775}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {3180, -4120}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {2921, -4428}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {935, -4095}, {-1, 0}], 
     InsetBox["\<\"co2[e]\"\>", {3651, -4754}, {-1, 0}], 
     InsetBox["\<\"2pg\"\>", {1093, -3125}, {-1, 0}], 
     InsetBox["\<\"lac-D[e]\"\>", {1025, -4835}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {2060, -3370}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4454, -4004}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {3987, -3529}, {-1, 0}], 
     InsetBox["\<\"o2\"\>", {4330, -1700}, {-1, 0}], 
     InsetBox["\<\"ac\"\>", {1745, -4385}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {1315, -3375}, {-1, 0}], 
     InsetBox["\<\"nh4\"\>", {4019, -4441}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4050, -3530}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1950, -3840}, {-1, 0}], 
     InsetBox["\<\"ru5p-D\"\>", {2155, -1235}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {2070, -3840}, {-1, 0}], 
     InsetBox["\<\"e4p\"\>", {1945, -2220}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {945, -3625}, {-1, 0}], 
     InsetBox["\<\"amp\"\>", {4035, -1050}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4865, -1180}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {1525, -3625}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2510, -1040}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {1165, -2805}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {3510, -1070}, {-1, 0}], 
     InsetBox["\<\"ac[e]\"\>", {1675, -4845}, {-1, 0}], 
     InsetBox["\<\"pyr\"\>", {1025, -3965}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4465, -1010}, {-1, 0}], 
     InsetBox["\<\"fum[e]\"\>", {2810, -670}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {2790, -4110}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {1165, -4065}, {-1, 0}], 
     InsetBox["\<\"nh4\"\>", {4190, -3790}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4450, -3692}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {1165, -1645}, {-1, 0}], 
     InsetBox["\<\"q8h2\"\>", {4635, -2190}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {4305, -1450}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4834, -3341}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {930, -4765}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4860, -1920}, {-1, 0}], 
     InsetBox["\<\"pyr\"\>", {1155, -1115}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4471, -3352}, {-1, 0}], 
     InsetBox["\<\"6pgc\"\>", {1827, -1235}, {-1, 0}], 
     InsetBox["\<\"succoa\"\>", {3704, -3203}, {-1, 0}], 
     InsetBox["\<\"actp\"\>", {1745, -4175}, {-1, 0}], 
     InsetBox["\<\"glu-L[e]\"\>", {4883, -3604}, {-1, 0}], 
     InsetBox["\<\"q8\"\>", {4685, -2070}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {1165, -2635}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {1240, -4770}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {3651, -4434}, {-1, 0}], 
     InsetBox["\<\"mal-L\"\>", {2583, -3178}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {4002, -3930}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {2380, -3220}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {1165, -1805}, {-1, 0}], 
     InsetBox["\<\"fdp\"\>", {1025, -1925}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {1880, -3890}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {4215, -1010}, {-1, 0}], 
     InsetBox["\<\"atp\"\>", {4474, -3753}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {1215, -3325}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {2040, -3420}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {1587, -1140}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {4385, -4278}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {4454, -3954}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {3593, -3710}, {-1, 0}], 
     InsetBox["\<\"mal-L[e]\"\>", {2640, -630}, {-1, 0}], 
     InsetBox["\<\"for[e]\"\>", {1500, -4810}, {-1, 0}], 
     InsetBox["\<\"succ[e]\"\>", {4944, -2904}, {-1, 0}], 
     InsetBox["\<\"oaa\"\>", {2692, -3724}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4825, -3723}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {2620, -4760}, {-1, 0}], 
     InsetBox["\<\"fru[e]\"\>", {300, -1390}, {-1, 0}], 
     InsetBox["\<\"nadph\"\>", {3740, -1310}, {-1, 0}], 
     InsetBox["\<\"coa\"\>", {3460, -2980}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4002, -3986}, {-1, 0}], 
     InsetBox["\<\"pi[e]\"\>", {2910, -4839}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {930, -4415}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {4485, -4278}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {3610, -1150}, {-1, 0}], 
     InsetBox["\<\"nh4\"\>", {4477, -3811}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {715, -3425}, {-1, 0}], 
     InsetBox["\<\"lac-D\"\>", {1089, -4349}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {728, -1565}, {-1, 0}], 
     InsetBox["\<\"h2o[e]\"\>", {3287, -4754}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {1835, -4225}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4305, -1380}, {-1, 0}], 
     InsetBox["\<\"pyr\"\>", {710, -1230}, {-1, 0}], 
     InsetBox["\<\"pyr[e]\"\>", {275, -3975}, {-1, 0}], 
     InsetBox["\<\"nadp\"\>", {1257, -1140}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1169, -2465}, {-1, 0}], 
     InsetBox["\<\"for\"\>", {1427, -4103}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {3814, -3051}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {2347, -3921}, {-1, 0}], 
     InsetBox["\<\"gln-L[e]\"\>", {4882, -4188}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {2690, -3320}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4850, -2590}, {-1, 0}], 
     InsetBox["\<\"g3p\"\>", {2410, -1900}, {-1, 0}], 
     InsetBox["\<\"adp\"\>", {3788, -3126}, {-1, 0}], 
     InsetBox["\<\"pi\"\>", {1685, -3515}, {-1, 0}], 
     InsetBox["\<\"akg\"\>", {3710, -3620}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {2280, -3510}, {-1, 0}], 
     InsetBox["\<\"co2\"\>", {3898, -3285}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {4850, -2259}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {2530, -740}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {2940, -1040}, {-1, 0}], 
     InsetBox["\<\"dhap\"\>", {825, -2195}, {-1, 0}], 
     InsetBox["\<\"h2o\"\>", {945, -3327}, {-1, 0}], 
     InsetBox["\<\"cit\"\>", {2979, -4013}, {-1, 0}], 
     InsetBox["\<\"r5p\"\>", {2420, -1590}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {2496, -4051}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {1665, -3865}, {-1, 0}], 
     InsetBox["\<\"nad\"\>", {4400, -2650}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {1635, -3475}, {-1, 0}], 
     InsetBox["\<\"h\"\>", {4456, -3109}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {935, -4045}, {-1, 0}], 
     InsetBox["\<\"h[e]\"\>", {345, -4065}, {-1, 0}], 
     InsetBox["\<\"q8\"\>", {3190, -2730}, {-1, 0}], 
     InsetBox["\<\"etoh\"\>", {2522, -4206}, {-1, 0}], 
     InsetBox["\<\"nadh\"\>", {3450, -1150}, {-1, 0}], 
     InsetBox["\<\"EX_o2(e)\"\>", {4970, -1690}, {-1, 0}], 
     InsetBox["\<\"PPCK\"\>", {1404, -3556}, {-1, 0}], 
     InsetBox["\<\"H2Ot\"\>", {3227, -4713}, {-1, 0}], 
     InsetBox["\<\"GLCpts\"\>", {1015, -733}, {-1, 0}], 
     InsetBox["\<\"GAPD\"\>", {1032, -2395}, {-1, 0}], 
     InsetBox["\<\"FRUpts2\"\>", {390, -1320}, {-1, 0}], 
     InsetBox["\<\"AKGDH\"\>", {3803, -3402}, {-1, 0}], 
     InsetBox["\<\"G6PDH2r\"\>", {1307, -1275}, {-1, 0}], 
     InsetBox["\<\"FRD7\"\>", {3110, -2580}, {-1, 0}], 
     InsetBox["\<\"GLUN\"\>", {4223, -3856}, {-1, 0}], 
     InsetBox["\<\"EX_glc(e)\"\>", {1073, -545}, {-1, 0}], 
     InsetBox["\<\"D-LACt2\"\>", {1020, -4610}, {-1, 0}], 
     InsetBox["\<\"CS\"\>", {2768, -3896}, {-1, 0}], 
     InsetBox["\<\"EX_pyr(e)\"\>", {170, -3910}, {-1, 0}], 
     InsetBox["\<\"PGM\"\>", {1045, -2995}, {-1, 0}], 
     InsetBox["\<\"GLUt2r\"\>", {4650, -3660}, {-1, 0}], 
     InsetBox["\<\"FUM\"\>", {2730, -3060}, {-1, 0}], 
     InsetBox["\<\"EX_h2o(e)\"\>", {3242, -4924}, {-1, 0}], 
     InsetBox["\<\"ACONTb\"\>", {3300, -4080}, {-1, 0}], 
     InsetBox["\<\"ACt2r\"\>", {1705, -4495}, {-1, 0}], 
     InsetBox["\<\"THD2\"\>", {3550, -750}, {-1, 0}], 
     InsetBox["\<\"ACALDt\"\>", {2194, -4728}, {-1, 0}], 
     InsetBox["\<\"ENO\"\>", {1034, -3225}, {-1, 0}], 
     InsetBox["\<\"ACALD\"\>", {2010, -3965}, {-1, 0}], 
     InsetBox["\<\"PGK\"\>", {1045, -2725}, {-1, 0}], 
     InsetBox["\<\"ADK1\"\>", {4115, -1260}, {-1, 0}], 
     InsetBox["\<\"GLUSy\"\>", {3978, -4123}, {-1, 0}], 
     InsetBox["\<\"PGL\"\>", {1637, -1275}, {-1, 0}], 
     InsetBox["\<\"GLNS\"\>", {4390, -3871}, {-1, 0}], 
     InsetBox["\<\"NADH16\"\>", {4790, -2550}, {-1, 0}], 
     InsetBox["\<\"PYK\"\>", {1075, -3715}, {-1, 0}], 
     InsetBox["\<\"CO2t\"\>", {3591, -4709}, {-1, 0}], 
     InsetBox["\<\"EX_succ(e)\"\>", {5010, -2850}, {-1, 0}], 
     InsetBox["\<\"GLNabc\"\>", {4433, -4131}, {-1, 0}], 
     InsetBox["\<\"EX_fru(e)\"\>", {180, -1420}, {-1, 0}], 
     InsetBox["\<\"PFL\"\>", {1335, -4005}, {-1, 0}], 
     InsetBox["\<\"GND\"\>", {1957, -1275}, {-1, 0}], 
     InsetBox["\<\"SUCOAS\"\>", {3655, -2997}, {-1, 0}], 
     InsetBox["\<\"TKT2\"\>", {1525, -1755}, {-1, 0}], 
     InsetBox["\<\"EX_lac-D(e)\"\>", {1025, -4925}, {-1, 0}], 
     InsetBox["\<\"EX_etoh(e)\"\>", {2520, -4910}, {-1, 0}], 
     InsetBox["\<\"RPE\"\>", {2065, -1425}, {-1, 0}], 
     InsetBox["\<\"O2t\"\>", {4790, -1640}, {-1, 0}], 
     InsetBox["\<\"LDH_D\"\>", {1035, -4175}, {-1, 0}], 
     InsetBox["\<\"TALA\"\>", {2201, -1990}, {-1, 0}], 
     InsetBox["\<\"MALS\"\>", {2921, -3378}, {-1, 0}], 
     InsetBox["\<\"EX_nh4(e)\"\>", {3973, -4918}, {-1, 0}], 
     InsetBox["\<\"PFK\"\>", {1023, -1730}, {-1, 0}], 
     InsetBox["\<\"SUCCt3\"\>", {4670, -2860}, {-1, 0}], 
     InsetBox["\<\"MALt2_2\"\>", {2560, -670}, {-1, 0}], 
     InsetBox["\<\"TPI\"\>", {955, -2225}, {-1, 0}], 
     InsetBox["\<\"EX_mal-L(e)\"\>", {2600, -510}, {-1, 0}], 
     InsetBox["\<\"EX_pi(e)\"\>", {2870, -4940}, {-1, 0}], 
     InsetBox["\<\"ALCD2x\"\>", {2360, -4170}, {-1, 0}], 
     InsetBox["\<\"ATPS4r\"\>", {4805, -1130}, {-1, 0}], 
     InsetBox["\<\"SUCDi\"\>", {3129, -2839}, {-1, 0}], 
     InsetBox["\<\"NADTRHD\"\>", {3520, -1290}, {-1, 0}], 
     InsetBox["\<\"FUMt2_2\"\>", {2890, -670}, {-1, 0}], 
     InsetBox["\<\"EX_glu-L(e)\"\>", {5000, -3580}, {-1, 0}], 
     InsetBox["\<\"ACKr\"\>", {1695, -4275}, {-1, 0}], 
     InsetBox["\<\"NH4t\"\>", {3958, -4718}, {-1, 0}], 
     InsetBox["\<\"PPS\"\>", {815, -3645}, {-1, 0}], 
     InsetBox["\<\"EX_co2(e)\"\>", {3597, -4914}, {-1, 0}], 
     InsetBox["\<\"RPI\"\>", {2325, -1415}, {-1, 0}], 
     InsetBox["\<\"FORt2\"\>", {1330, -4620}, {-1, 0}], 
     InsetBox["\<\"PDH\"\>", {1490, -3935}, {-1, 0}], 
     InsetBox["\<\"PPC\"\>", {1424, -3456}, {-1, 0}], 
     InsetBox["\<\"CYTBD\"\>", {4780, -1870}, {-1, 0}], 
     InsetBox["\<\"EX_fum(e)\"\>", {2850, -510}, {-1, 0}], 
     InsetBox["\<\"EX_for(e)\"\>", {1450, -4925}, {-1, 0}], 
     InsetBox["\<\"GLUDy\"\>", {4089, -3658}, {-1, 0}], 
     InsetBox["\<\"PTAr\"\>", {1695, -4085}, {-1, 0}], 
     InsetBox["\<\"FBA\"\>", {1065, -1995}, {-1, 0}], 
     InsetBox["\<\"FBP\"\>", {815, -1715}, {-1, 0}], 
     InsetBox["\<\"EX_gln-L(e)\"\>", {5010, -4130}, {-1, 0}], 
     InsetBox["\<\"SUCCt2_2\"\>", {4666, -3047}, {-1, 0}], 
     InsetBox["\<\"ACONTa\"\>", {3070, -4080}, {-1, 0}], 
     InsetBox["\<\"ICL\"\>", {3437, -3857}, {-1, 0}], 
     InsetBox["\<\"PIt2r\"\>", {2894, -4743}, {-1, 0}], 
     InsetBox["\<\"ATPM\"\>", {4235, -1260}, {-1, 0}], 
     InsetBox["\<\"EX_akg(e)\"\>", {5020, -3200}, {-1, 0}], 
     InsetBox["\<\"AKGt2r\"\>", {4661, -3218}, {-1, 0}], 
     InsetBox["\<\"PGI\"\>", {1028, -1395}, {-1, 0}], 
     InsetBox["\<\"ETOHt2r\"\>", {2474, -4718}, {-1, 0}], 
     InsetBox["\<\"MDH\"\>", {2608, -3400}, {-1, 0}], 
     InsetBox["\<\"FORti\"\>", {1470, -4620}, {-1, 0}], 
     InsetBox["\<\"PYRt2r\"\>", {510, -3970}, {-1, 0}], 
     InsetBox["\<\"EX_acald(e)\"\>", {2230, -4940}, {-1, 0}], 
     InsetBox["\<\"ICDHyr\"\>", {3616, -3866}, {-1, 0}], 
     InsetBox["\<\"ME2\"\>", {2280, -3400}, {-1, 0}], 
     InsetBox["\<\"TKT1\"\>", {2198, -1690}, {-1, 0}], 
     InsetBox["\<\"EX_ac(e)\"\>", {1745, -4935}, {-1, 0}], 
     InsetBox["\<\"EX_h(e)\"\>", {4986, -2220}, {-1, 0}], 
     InsetBox["\<\"ME1\"\>", {2250, -3320}, {-1, 0}], 
     StyleBox[{},
      60 -> Text["2", {2480, -700}, {-1, 0}],
      70 -> Text["4", {4280, -2570}, {-1, 0}],
      0 -> Text["2", {4330, -1860}, {-1, 0}]]},
    StripOnInput->False,
    FontFamily->"Arial",
    FontSize->Scaled[0.007343436331430821]]},
  ImageSize->350]], "Output",
 CellChangeTimes->{3.6775728913024497`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"ecoli", ",", 
   RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577994491450758*^9, 3.577994495834564*^9}, {
  3.5779980060148563`*^9, 3.577998024088582*^9}, {3.5779981432762127`*^9, 
  3.577998147861*^9}, {3.577998239977159*^9, 3.577998240191633*^9}, {
  3.6219130582371473`*^9, 3.621913078650537*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    RasterBox[CompressedData["
1:eJzt1EGO40YMBdAGcpKcJPssc4QBss7Vc4RMEBATEObIsqvMKul9oPGaskxR
UpV//fbXH3/+8vX19fv3v2/f//79/7/8/RtJkuQ1jRzV+ThJkuTdzDk6r6pJ
kvcyUtW7mHN0nLyykd33NUne3UhVkyRJ7m6V/Hn3nLyXEeuQJHkHc47Oq2qS
+5rTPc/d5udcI1XNexmxHkg+a6SqV3f3+flZc7rnYa853fOQJMl1zOmeh9zJ
SFVzTXO657makU/vi1evmzOq/6vz7PK+crrvg3sYWX1fcC8jz66rs+ff7b5G
9eFrRjz/x0ZmrfNX+1exH/mOOd3zkM+Ys3v/fJ2qnjUPx5rjPd7DnO4+n163
1fe638tqz5n3NKd7Hl7TSFVzrhHPn51Gjup3j5Mk72WkqskVrGLdkjxrTvc8
JDnbnO55dp+TJEmub073POQrRqqaveZ0z7OKkU+v267rrma+71zP6j/7uqP3
49nzV/PZ+fPn1feO+pBk5KjOqc5f3d3nr97L2futjnffF69p5N11eHR+1Xd1
j+6L5L7mfOp6Vb2aOVe/LvmOVY7Wda7tC5KrmTP6fLLTSFVzjJGjOh8nSZKs
zOmeh+S8fV7VvKc53fOQKxqpapIkybuZ0z0PyXn7vKpJ9u3LyNn9Wx3vvq+r
GfGcSXJvI1XNseasdt38+bNzPtu/+zms9tzI/5vTPQ+vYc5V1mHXfY3qw9fM
6Z5nNXNG93m2f/U9+5HvGKlqkiRnmNM9D8nrGKlqkvbLKkZyXR1/9rxnj5Mk
OcOc7nlIkvyZkaomRxqx3viOOd3zkCTPGalqkvW+iRwdJ0mSvKo53fOQvK+R
quYYI0d1Pt49bzXXu/Of7T973Z6df9ZzXu29v3p8l9+lWfPf1ZxP9Rl1XZL7
mnOVPlXfo/rZ646ac1SfXa7rvubOmfuN7r+bOVeZp+ozqv8uz/MuRu6+r/N9
53r161Z9Zh9/9b6qjOq/63s/e7yr/6j3uNrzHD1/1Xf135NR/avzR/XpWp9V
n1H9V/u94jWMfHrdklxnvz/7vWfPJ0mSnG1O9zwkmY1UNfmOOd3z8OfmnD0/
f+/V493PgSRJ8qw53fOQ5CwjVU3OMKd7Hj42cvTecn32vVfHSZIkVzOnex6S
/LSRqiY/aU73PFc1x+8DZ5rTPQ9J7m5O9zzVfFW9uznd85Ds3+/58+p7R8e7
75ckK3O65yHJ1Y1UNcl1zDl7fv7es31I7mfEfifJr4fpnockdzVS1ST79mWO
fUqSc41UNcl+I0d1Pk7uZKSqSZL3NOfoOHkFI1VNkvyMOd3znJ27qlfvT54x
x7rdy8i772VUH5L7m9M9D0nysZGqJlcwp3se+44kSV7VnO55SPJqRqr61X7v
9iF5HSNVTZL8epjuedhjpKp3Xz+fnjNf5+i6Z88nZxi56jrMWe13w/s9dx+7
zk/SfidJnjNS1eQnjKyyDlebh2saeXadnD2/a/6uObuuO+s+cna/L5Kv/w50
z9N1/1VNkiQ5ypzueUjy00aqmiTPmtM9D0nymkaqmlzBKrPW7ez+7DVy9v3m
dM9DklzLSFXv3r/KrHk41kj1Pr3Haxp59/2O6tN93Zzu97PKc+Y9jey+r0mS
54xUNcl1jRzV+ThJkuTqRqqaXw8z+nxyhjnd84y6n6p+9/zdzOmeh7yzOd3z
kCT5CSNVzXtaZdd1svv8JEmSYU73PCTJexmpavIdc6xPkiRJcp6RqiZXMKd7
HpIkr2RO9zw8Z6SqSZJfD9M9D8n+/Z4/PzqfJDnHnO55SNqnJMm1jFQ1OdKI
9Ubyh/8A4uswFQ==
     "], {{0, 0}, {98, 74}}, {0, 1}], Frame -> True, 
    FrameLabel -> {None, None}, FrameTicks -> {{{{54.5, 
         FormBox["20", TraditionalForm]}, {34.5, 
         FormBox["40", TraditionalForm]}, {14.5, 
         FormBox["60", TraditionalForm]}}, {{73.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["13dpg", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["13dpg", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["13dpg", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["13dpg", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["13dpg", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {72.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["2pg", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["2pg", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["2pg", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["2pg", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["2pg", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {71.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["3pg", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["3pg", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["3pg", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["3pg", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["3pg", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {70.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["6pgc", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["6pgc", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["6pgc", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["6pgc", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["6pgc", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {69.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["6pgl", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["6pgl", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["6pgl", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["6pgl", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["6pgl", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {68.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["ac", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["ac", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["ac", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["ac", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["ac", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {67.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["ac", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["ac", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["ac", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["ac", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["ac", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {66.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["acald", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["acald", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["acald", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["acald", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["acald", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {65.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["acald", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["acald", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["acald", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["acald", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["acald", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {64.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["accoa", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["accoa", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["accoa", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["accoa", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["accoa", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {63.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["acon-C", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["acon-C", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["acon-C", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["acon-C", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["acon-C", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {62.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["actp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["actp", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["actp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["actp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["actp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {61.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["adp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["adp", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["adp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["adp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["adp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {60.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["akg", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["akg", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["akg", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["akg", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["akg", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {59.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["akg", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["akg", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["akg", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["akg", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["akg", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {58.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["amp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["amp", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["amp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["amp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["amp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {57.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["cit", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["cit", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["cit", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["cit", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["cit", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {56.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["co2", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["co2", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["co2", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["co2", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["co2", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {55.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["co2", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["co2", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["co2", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["co2", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["co2", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {54.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["coa", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["coa", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["coa", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["coa", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["coa", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {53.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["dhap", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["dhap", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["dhap", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["dhap", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["dhap", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {52.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["e4p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["e4p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["e4p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["e4p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["e4p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {51.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["etoh", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["etoh", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["etoh", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["etoh", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["etoh", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {50.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["etoh", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["etoh", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["etoh", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["etoh", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["etoh", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {49.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["f6p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["f6p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["f6p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["f6p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["f6p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {48.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["fdp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["fdp", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["fdp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["fdp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["fdp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {47.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["for", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["for", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["for", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["for", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["for", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {46.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["for", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["for", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["for", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["for", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["for", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {45.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["fru", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["fru", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["fru", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["fru", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["fru", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {44.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["fum", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["fum", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["fum", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["fum", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["fum", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {43.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["fum", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["fum", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["fum", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["fum", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["fum", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {42.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["g3p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["g3p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["g3p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["g3p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["g3p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {41.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["g6p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["g6p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["g6p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["g6p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["g6p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {40.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glc-D", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glc-D", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glc-D", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glc-D", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glc-D", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {39.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["gln-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["gln-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["gln-L", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["gln-L", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {38.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["gln-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["gln-L", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["gln-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["gln-L", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["gln-L", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {37.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glu-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glu-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glu-L", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glu-L", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {36.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glu-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glu-L", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glu-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glu-L", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glu-L", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {35.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glx", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glx", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glx", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glx", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glx", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {34.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["h", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["h", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["h", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["h", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["h", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {33.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["h", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["h", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["h", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["h", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["h", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {32.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["h2o", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["h2o", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["h2o", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["h2o", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["h2o", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {31.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["h2o", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["h2o", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["h2o", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["h2o", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["h2o", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {30.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["icit", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["icit", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["icit", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["icit", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["icit", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {29.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["lac-D", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["lac-D", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["lac-D", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["lac-D", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["lac-D", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {28.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["lac-D", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["lac-D", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["lac-D", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["lac-D", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["lac-D", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {27.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["mal-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["mal-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["mal-L", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["mal-L", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {26.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["mal-L", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["mal-L", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["mal-L", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["mal-L", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["mal-L", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {25.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nad", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nad", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nad", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nad", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nad", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {24.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nadp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nadp", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nadp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nadp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nadp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {23.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nh4", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nh4", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nh4", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nh4", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nh4", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {22.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nh4", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nh4", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nh4", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nh4", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nh4", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {21.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["o2", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["o2", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["o2", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["o2", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["o2", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {20.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["o2", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["o2", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["o2", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["o2", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["o2", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {19.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["oaa", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["oaa", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["oaa", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["oaa", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["oaa", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {18.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["pep", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["pep", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["pep", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["pep", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["pep", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {17.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["pi", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["pi", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["pi", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["pi", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["pi", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {16.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["pyr", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["pyr", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["pyr", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["pyr", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["pyr", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {15.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["pyr", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["pyr", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["pyr", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["pyr", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["pyr", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {14.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["r5p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["r5p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["r5p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["r5p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["r5p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {13.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["ru5p-D", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["ru5p-D", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["ru5p-D", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["ru5p-D", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["ru5p-D", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {12.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["succ", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["succ", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["succ", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["succ", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["succ", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {11.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["atp", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["atp", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["atp", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["atp", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["atp", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {10.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nadh", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nadh", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nadh", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nadh", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nadh", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {9.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["nadph", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["nadph", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["nadph", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["nadph", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["nadph", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {8.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["pi", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["pi", "e"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["pi", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["pi", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["pi", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {7.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["q8", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["q8", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["q8", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["q8", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["q8", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {6.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["q8h2", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["q8h2", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["q8h2", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["q8h2", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["q8h2", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {5.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["s7p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["s7p", "c"], Editable -> False, Selectable -> 
                False], StandardForm], StandardForm, Editable -> True], 
             FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["s7p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["s7p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["s7p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {4.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["succ", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["e", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["succ", "e"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["succ", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["e", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["succ", "e"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["succ", "e"]], "Tooltip"]& ], 
          TraditionalForm]}, {3.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["succoa", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["succoa", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["succoa", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["succoa", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["succoa", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {2.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["xu5p-D", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["xu5p-D", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["xu5p-D", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["xu5p-D", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["xu5p-D", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {1.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glyc", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glyc", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glyc", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glyc", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glyc", "c"]], "Tooltip"]& ], 
          TraditionalForm]}, {0.5, 
         FormBox[
          TagBox[
           TooltipBox[
            StyleBox[
             TagBox[
              FormBox[
               InterpretationBox[
                SuperscriptBox[
                 StyleBox["glyc3p", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True], 
                 StyleBox["c", 
                  RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                  False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
                Toolbox`metabolite["glyc3p", "c"], Editable -> False, 
                Selectable -> False], StandardForm], StandardForm, Editable -> 
              True], FontSize -> Scaled[0.01], StripOnInput -> False], 
            InterpretationBox[
             SuperscriptBox[
              StyleBox["glyc3p", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True], 
              StyleBox["c", 
               RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
               False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
             Toolbox`metabolite["glyc3p", "c"], Editable -> False, Selectable -> 
             False]], Annotation[#, 
            TraditionalForm[
             Toolbox`metabolite["glyc3p", "c"]], "Tooltip"]& ], 
          TraditionalForm]}}}, {{{0.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACALD\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["acald", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["acald", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ACALD", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACALD", {
                 Toolbox`metabolite["acald", "c"], 
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACALD", {
               Toolbox`metabolite["acald", "c"], 
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {1.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACALDt\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["acald", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["acald", "e"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["acald", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["acald", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["ACALDt", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACALDt", {
                 Toolbox`metabolite["acald", "e"]}, {
                 Toolbox`metabolite["acald", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACALDt", {
               Toolbox`metabolite["acald", "e"]}, {
               Toolbox`metabolite["acald", "c"]}, {1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {2.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACKr\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["ac", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["ac", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["actp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["actp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ACKr", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACKr", {
                 Toolbox`metabolite["ac", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["actp", "c"], 
                 Toolbox`metabolite["adp", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACKr", {
               Toolbox`metabolite["ac", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["actp", "c"], 
               Toolbox`metabolite["adp", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {3.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACONTa\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["cit", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["cit", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["acon-C", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["acon-C", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ACONTa", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACONTa", {
                 Toolbox`metabolite["cit", "c"]}, {
                 Toolbox`metabolite["acon-C", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACONTa", {
               Toolbox`metabolite["cit", "c"]}, {
               Toolbox`metabolite["acon-C", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {4.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACONTb\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["acon-C", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["acon-C", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["icit", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["icit", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["ACONTb", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACONTb", {
                 Toolbox`metabolite["acon-C", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["icit", "c"]}, {1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACONTb", {
               Toolbox`metabolite["acon-C", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["icit", "c"]}, {1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {5.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ACt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["ac", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["ac", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["ac", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["ac", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ACt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ACt2r", {
                 Toolbox`metabolite["ac", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["ac", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ACt2r", {
               Toolbox`metabolite["ac", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["ac", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {6.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ADK1\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["amp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["amp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ADK1", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ADK1", {
                 Toolbox`metabolite["amp", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"]}, {1, 1, 2}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ADK1", {
               Toolbox`metabolite["amp", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"]}, {1, 1, 2}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {7.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"AKGDH\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succoa", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["AKGDH", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["AKGDH", {
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["nadh", "c"], 
                 Toolbox`metabolite["succoa", "c"]}, {1, 1, 1, 1, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["AKGDH", {
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["nadh", "c"], 
               Toolbox`metabolite["succoa", "c"]}, {1, 1, 1, 1, 1, 1}, 
              False]], "Tooltip"]& ], TraditionalForm]}, {8.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"AKGt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["AKGt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["AKGt2r", {
                 Toolbox`metabolite["akg", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["AKGt2r", {
               Toolbox`metabolite["akg", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {9.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ALCD2x\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["etoh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["etoh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["acald", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["acald", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ALCD2x", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ALCD2x", {
                 Toolbox`metabolite["etoh", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["acald", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ALCD2x", {
               Toolbox`metabolite["etoh", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["acald", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {10.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ATPM\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ATPM", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ATPM", {
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ATPM", {
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {11.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ATPS4r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    RowBox[{"4", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    RowBox[{"3", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ATPS4r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ATPS4r", {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["pi", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {1, 4, 1, 3, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ATPS4r", {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["pi", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["atp", "c"]}, {1, 4, 1, 3, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {12.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"Biomass_Ecoli_c<<18>>\"", FontSize -> Scaled[0.01], 
              StripOnInput -> False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"1.496`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["3pg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["3pg", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"3.7478`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"59.81`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.361`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["e4p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["e4p", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.0709`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.129`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.205`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g6p", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.2557`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"4.9414`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"59.81`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"3.547`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"13.0279`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"1.7867`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["oaa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["oaa", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.5191`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"2.8328`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.8977`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["r5p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["r5p", "c"], Editable -> False, 
                    Selectable -> False]}]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"59.81`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"4.1182`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"3.7478`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"59.81`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"3.547`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"13.0279`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"59.81`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}]}], 
                StyleBox["Biomass_Ecoli_core_N(w/GAM)_Nmet2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["Biomass_Ecoli_core_N(w/GAM)_Nmet2", {
                 Toolbox`metabolite["3pg", "c"], 
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["e4p", "c"], 
                 Toolbox`metabolite["f6p", "c"], 
                 Toolbox`metabolite["g3p", "c"], 
                 Toolbox`metabolite["g6p", "c"], 
                 Toolbox`metabolite["gln-L", "c"], 
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["oaa", "c"], 
                 Toolbox`metabolite["pep", "c"], 
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["r5p", "c"], 
                 Toolbox`metabolite["atp", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadp", "c"], 
                 Toolbox`metabolite["pi", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1.496, 3.7478, 0.361, 
                0.0709, 0.129, 0.205, 0.2557, 4.9414, 59.81, 3.547, 1.7867, 
                0.5191, 2.8328, 0.8977, 59.81, 13.0279, 59.81, 4.1182, 3.7478,
                 59.81, 13.0279, 59.81, 3.547}, False], Editable -> False, 
               Selectable -> False], StandardForm], StandardForm, Editable -> 
             True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["Biomass_Ecoli_core_N(w/GAM)_Nmet2", {
               Toolbox`metabolite["3pg", "c"], 
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["e4p", "c"], 
               Toolbox`metabolite["f6p", "c"], 
               Toolbox`metabolite["g3p", "c"], 
               Toolbox`metabolite["g6p", "c"], 
               Toolbox`metabolite["gln-L", "c"], 
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["oaa", "c"], 
               Toolbox`metabolite["pep", "c"], 
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["r5p", "c"], 
               Toolbox`metabolite["atp", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadp", "c"], 
               Toolbox`metabolite["pi", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1.496, 3.7478, 0.361, 
              0.0709, 0.129, 0.205, 0.2557, 4.9414, 59.81, 3.547, 1.7867, 
              0.5191, 2.8328, 0.8977, 59.81, 13.0279, 59.81, 4.1182, 3.7478, 
              59.81, 13.0279, 59.81, 3.547}, False]], "Tooltip"]& ], 
          TraditionalForm]}, {13.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"CO2t\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["co2", "e"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["co2", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["CO2t", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["CO2t", {
                 Toolbox`metabolite["co2", "e"]}, {
                 Toolbox`metabolite["co2", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["CO2t", {
               Toolbox`metabolite["co2", "e"]}, {
               Toolbox`metabolite["co2", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {14.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"CS\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["oaa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["oaa", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["cit", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["cit", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["CS", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["CS", {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["oaa", "c"]}, {
                 Toolbox`metabolite["cit", "c"], 
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["CS", {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["oaa", "c"]}, {
               Toolbox`metabolite["cit", "c"], 
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {15.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"CYTBD\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    RowBox[{"0.5`", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["o2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["o2", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8h2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8h2", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["CYTBD", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["CYTBD", {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["o2", "c"], 
                 Toolbox`metabolite["q8h2", "c"]}, {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["q8", "c"]}, {2, 0.5, 1, 2, 1, 1}, False],
                Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["CYTBD", {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["o2", "c"], 
               Toolbox`metabolite["q8h2", "c"]}, {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["q8", "c"]}, {2, 0.5, 1, 2, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {16.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"D_LACt2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["lac-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["lac-D", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["lac-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["lac-D", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["D_LACt2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["D_LACt2", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["lac-D", "e"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["lac-D", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["D_LACt2", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["lac-D", "e"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["lac-D", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {17.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ENO\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["2pg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["2pg", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ENO", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ENO", {
                 Toolbox`metabolite["2pg", "c"]}, {
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["pep", "c"]}, {1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ENO", {
               Toolbox`metabolite["2pg", "c"]}, {
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["pep", "c"]}, {1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {18.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ETOHt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["etoh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["etoh", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["etoh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["etoh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ETOHt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ETOHt2r", {
                 Toolbox`metabolite["etoh", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["etoh", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ETOHt2r", {
               Toolbox`metabolite["etoh", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["etoh", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {19.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FBA\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["fdp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["fdp", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["dhap", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["dhap", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["FBA", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FBA", {
                 Toolbox`metabolite["fdp", "c"]}, {
                 Toolbox`metabolite["dhap", "c"], 
                 Toolbox`metabolite["g3p", "c"]}, {1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FBA", {
               Toolbox`metabolite["fdp", "c"]}, {
               Toolbox`metabolite["dhap", "c"], 
               Toolbox`metabolite["g3p", "c"]}, {1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {20.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FBP\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fdp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fdp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["FBP", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FBP", {
                 Toolbox`metabolite["fdp", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["f6p", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FBP", {
               Toolbox`metabolite["fdp", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["f6p", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {21.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FORt2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["for", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["for", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["FORt2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FORt2", {
                 Toolbox`metabolite["for", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["for", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FORt2", {
               Toolbox`metabolite["for", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["for", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {22.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FORti\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["for", "c"], Editable -> False, 
                   Selectable -> False], "\[RightArrow]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["for", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["FORti", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FORti", {
                 Toolbox`metabolite["for", "c"]}, {
                 Toolbox`metabolite["for", "e"]}, {1, 1}, False], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FORti", {
               Toolbox`metabolite["for", "c"]}, {
               Toolbox`metabolite["for", "e"]}, {1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {23.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FRD7\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fum", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8h2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8h2", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["FRD7", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FRD7", {
                 Toolbox`metabolite["fum", "c"], 
                 Toolbox`metabolite["q8h2", "c"]}, {
                 Toolbox`metabolite["succ", "c"], 
                 Toolbox`metabolite["q8", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FRD7", {
               Toolbox`metabolite["fum", "c"], 
               Toolbox`metabolite["q8h2", "c"]}, {
               Toolbox`metabolite["succ", "c"], 
               Toolbox`metabolite["q8", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {24.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FRUpts2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fru", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fru", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["FRUpts2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FRUpts2", {
                 Toolbox`metabolite["fru", "e"], 
                 Toolbox`metabolite["pep", "c"]}, {
                 Toolbox`metabolite["f6p", "c"], 
                 Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FRUpts2", {
               Toolbox`metabolite["fru", "e"], 
               Toolbox`metabolite["pep", "c"]}, {
               Toolbox`metabolite["f6p", "c"], 
               Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {25.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FUM\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fum", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["FUM", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FUM", {
                 Toolbox`metabolite["fum", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["mal-L", "c"]}, {1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FUM", {
               Toolbox`metabolite["fum", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["mal-L", "c"]}, {1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {26.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"FUMt2_2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fum", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fum", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}]}], 
                StyleBox["FUMt2_2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["FUMt2_2", {
                 Toolbox`metabolite["fum", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["fum", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 2, 1, 2}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["FUMt2_2", {
               Toolbox`metabolite["fum", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["fum", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 2, 1, 2}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {27.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"G6PDH2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g6p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["6pgl", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["6pgl", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["G6PDH2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["G6PDH2r", {
                 Toolbox`metabolite["g6p", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {
                 Toolbox`metabolite["6pgl", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["G6PDH2r", {
               Toolbox`metabolite["g6p", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {
               Toolbox`metabolite["6pgl", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {28.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GAPD\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["13dpg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["13dpg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GAPD", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GAPD", {
                 Toolbox`metabolite["g3p", "c"], 
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {
                 Toolbox`metabolite["13dpg", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GAPD", {
               Toolbox`metabolite["g3p", "c"], 
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["pi", "c"]}, {
               Toolbox`metabolite["13dpg", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {29.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLCpts\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glc-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glc-D", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g6p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLCpts", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLCpts", {
                 Toolbox`metabolite["glc-D", "e"], 
                 Toolbox`metabolite["pep", "c"]}, {
                 Toolbox`metabolite["g6p", "c"], 
                 Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLCpts", {
               Toolbox`metabolite["glc-D", "e"], 
               Toolbox`metabolite["pep", "c"]}, {
               Toolbox`metabolite["g6p", "c"], 
               Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {30.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLNS\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nh4", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLNS", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLNS", {
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["nh4", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["gln-L", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLNS", {
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["nh4", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["gln-L", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1, 1}, False]],
             "Tooltip"]& ], TraditionalForm]}, {31.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLNabc\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLNabc", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLNabc", {
                 Toolbox`metabolite["gln-L", "e"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["gln-L", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLNabc", {
               Toolbox`metabolite["gln-L", "e"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["gln-L", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1, 1}, False]],
             "Tooltip"]& ], TraditionalForm]}, {32.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLUDy\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nh4", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLUDy", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLUDy", {
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nh4", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1, 1, 1}, 
                True], Editable -> False, Selectable -> False], StandardForm],
              StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLUDy", {
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nh4", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1, 1, 1}, 
              True]], "Tooltip"]& ], TraditionalForm]}, {33.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLUN\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nh4", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLUN", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLUN", {
                 Toolbox`metabolite["gln-L", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["nh4", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLUN", {
               Toolbox`metabolite["gln-L", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["nh4", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {34.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLUSy\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["gln-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLUSy", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLUSy", {
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["gln-L", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {1, 1, 1, 1, 2, 1}, False],
                Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLUSy", {
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["gln-L", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {1, 1, 1, 1, 2, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {35.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLUt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glu-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLUt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLUt2r", {
                 Toolbox`metabolite["glu-L", "e"], 
                 Toolbox`metabolite["h", "e"]}, {
                 Toolbox`metabolite["glu-L", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLUt2r", {
               Toolbox`metabolite["glu-L", "e"], 
               Toolbox`metabolite["h", "e"]}, {
               Toolbox`metabolite["glu-L", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {36.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GND\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["6pgc", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["6pgc", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["ru5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["ru5p-D", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GND", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GND", {
                 Toolbox`metabolite["6pgc", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["ru5p-D", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GND", {
               Toolbox`metabolite["6pgc", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["ru5p-D", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {37.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"H2Ot\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["h2o", "e"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["h2o", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["H2Ot", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["H2Ot", {
                 Toolbox`metabolite["h2o", "e"]}, {
                 Toolbox`metabolite["h2o", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["H2Ot", {
               Toolbox`metabolite["h2o", "e"]}, {
               Toolbox`metabolite["h2o", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {38.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ICDHyr\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["icit", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["icit", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["akg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ICDHyr", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ICDHyr", {
                 Toolbox`metabolite["icit", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {
                 Toolbox`metabolite["akg", "c"], 
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ICDHyr", {
               Toolbox`metabolite["icit", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {
               Toolbox`metabolite["akg", "c"], 
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {39.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ICL\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["icit", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["icit", "c"], Editable -> False, 
                   Selectable -> False], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glx", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glx", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ICL", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ICL", {
                 Toolbox`metabolite["icit", "c"]}, {
                 Toolbox`metabolite["glx", "c"], 
                 Toolbox`metabolite["succ", "c"]}, {1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ICL", {
               Toolbox`metabolite["icit", "c"]}, {
               Toolbox`metabolite["glx", "c"], 
               Toolbox`metabolite["succ", "c"]}, {1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {40.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"LDH_D\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["lac-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["lac-D", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["LDH_D", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["LDH_D", {
                 Toolbox`metabolite["lac-D", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["LDH_D", {
               Toolbox`metabolite["lac-D", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {41.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"MALS\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glx", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glx", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["MALS", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["MALS", {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["glx", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["mal-L", "c"]}, {1, 1, 1, 1, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["MALS", {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["glx", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["mal-L", "c"]}, {1, 1, 1, 1, 1, 1}, False]],
             "Tooltip"]& ], TraditionalForm]}, {42.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"MALt2_2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "e"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["MALt2_2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["MALt2_2", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["mal-L", "e"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["mal-L", "c"]}, {2, 1, 2, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["MALt2_2", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["mal-L", "e"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["mal-L", "c"]}, {2, 1, 2, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {43.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"MDH\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["oaa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["oaa", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["MDH", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["MDH", {
                 Toolbox`metabolite["mal-L", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["oaa", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["MDH", {
               Toolbox`metabolite["mal-L", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["oaa", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {44.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ME1\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ME1", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ME1", {
                 Toolbox`metabolite["mal-L", "c"], 
                 Toolbox`metabolite["nad", "c"]}, {
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ME1", {
               Toolbox`metabolite["mal-L", "c"], 
               Toolbox`metabolite["nad", "c"]}, {
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {45.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"ME2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["mal-L", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["ME2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["ME2", {
                 Toolbox`metabolite["mal-L", "c"], 
                 Toolbox`metabolite["nadp", "c"]}, {
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["ME2", {
               Toolbox`metabolite["mal-L", "c"], 
               Toolbox`metabolite["nadp", "c"]}, {
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {46.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"NADH16\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"4", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"3", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8h2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8h2", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["NADH16", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["NADH16", {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadh", "c"], 
                 Toolbox`metabolite["q8", "c"]}, {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["q8h2", "c"]}, {4, 1, 1, 3, 1, 1}, False],
                Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["NADH16", {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadh", "c"], 
               Toolbox`metabolite["q8", "c"]}, {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["q8h2", "c"]}, {4, 1, 1, 3, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {47.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"NADTRHD\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["NADTRHD", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["NADTRHD", {
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {
                 Toolbox`metabolite["nadp", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["NADTRHD", {
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {
               Toolbox`metabolite["nadp", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {48.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"NH4t\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["nh4", "e"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["nh4", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["NH4t", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["NH4t", {
                 Toolbox`metabolite["nh4", "e"]}, {
                 Toolbox`metabolite["nh4", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["NH4t", {
               Toolbox`metabolite["nh4", "e"]}, {
               Toolbox`metabolite["nh4", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {49.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"O2t\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["o2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["o2", "e"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["o2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["o2", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["O2t", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["O2t", {
                 Toolbox`metabolite["o2", "e"]}, {
                 Toolbox`metabolite["o2", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["O2t", {
               Toolbox`metabolite["o2", "e"]}, {
               Toolbox`metabolite["o2", "c"]}, {1, 1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {50.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PDH\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PDH", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PDH", {
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["pyr", "c"]}, {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, False],
                Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PDH", {
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["pyr", "c"]}, {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {1, 1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {51.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PFK\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fdp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fdp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PFK", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PFK", {
                 Toolbox`metabolite["f6p", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["fdp", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PFK", {
               Toolbox`metabolite["f6p", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["fdp", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {52.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PFL\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["for", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PFL", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PFL", {
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["pyr", "c"]}, {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["for", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PFL", {
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["pyr", "c"]}, {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["for", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {53.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PGI\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["g6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["g6p", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["f6p", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["PGI", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PGI", {
                 Toolbox`metabolite["g6p", "c"]}, {
                 Toolbox`metabolite["f6p", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PGI", {
               Toolbox`metabolite["g6p", "c"]}, {
               Toolbox`metabolite["f6p", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {54.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PGK\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["3pg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["3pg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["13dpg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["13dpg", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PGK", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PGK", {
                 Toolbox`metabolite["3pg", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["13dpg", "c"], 
                 Toolbox`metabolite["adp", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PGK", {
               Toolbox`metabolite["3pg", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["13dpg", "c"], 
               Toolbox`metabolite["adp", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {55.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PGL\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["6pgl", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["6pgl", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["6pgc", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["6pgc", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PGL", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PGL", {
                 Toolbox`metabolite["6pgl", "c"], 
                 Toolbox`metabolite["h2o", "c"]}, {
                 Toolbox`metabolite["6pgc", "c"], 
                 Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PGL", {
               Toolbox`metabolite["6pgl", "c"], 
               Toolbox`metabolite["h2o", "c"]}, {
               Toolbox`metabolite["6pgc", "c"], 
               Toolbox`metabolite["h", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {56.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PGM\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["2pg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["2pg", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["3pg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["3pg", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["PGM", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PGM", {
                 Toolbox`metabolite["2pg", "c"]}, {
                 Toolbox`metabolite["3pg", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PGM", {
               Toolbox`metabolite["2pg", "c"]}, {
               Toolbox`metabolite["3pg", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {57.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PIt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PIt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PIt2r", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["pi", "e"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PIt2r", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["pi", "e"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {58.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PPC\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["oaa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["oaa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PPC", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PPC", {
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["pep", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["oaa", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PPC", {
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["pep", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["oaa", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {59.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PPCK\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["oaa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["oaa", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["co2", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PPCK", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PPCK", {
                 Toolbox`metabolite["oaa", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["co2", "c"], 
                 Toolbox`metabolite["pep", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PPCK", {
               Toolbox`metabolite["oaa", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["co2", "c"], 
               Toolbox`metabolite["pep", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {60.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PPS\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h2o", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["amp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["amp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PPS", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PPS", {
                 Toolbox`metabolite["h2o", "c"], 
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["amp", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pep", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 2, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PPS", {
               Toolbox`metabolite["h2o", "c"], 
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["amp", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pep", "c"], 
               Toolbox`metabolite["pi", "c"]}, {1, 1, 1, 1, 2, 1, 1}, False]],
             "Tooltip"]& ], TraditionalForm]}, {61.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PTAr\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["accoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["accoa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["actp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["actp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PTAr", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PTAr", {
                 Toolbox`metabolite["accoa", "c"], 
                 Toolbox`metabolite["pi", "c"]}, {
                 Toolbox`metabolite["actp", "c"], 
                 Toolbox`metabolite["coa", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PTAr", {
               Toolbox`metabolite["accoa", "c"], 
               Toolbox`metabolite["pi", "c"]}, {
               Toolbox`metabolite["actp", "c"], 
               Toolbox`metabolite["coa", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {62.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PYK\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pep", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pep", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PYK", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PYK", {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pep", "c"]}, {
                 Toolbox`metabolite["pyr", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PYK", {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pep", "c"]}, {
               Toolbox`metabolite["pyr", "c"], 
               Toolbox`metabolite["atp", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {63.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"PYRt2r\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "e"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pyr", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["PYRt2r", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["PYRt2r", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["pyr", "e"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["PYRt2r", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["pyr", "e"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["pyr", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {64.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"RPE\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["ru5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["ru5p-D", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["xu5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["xu5p-D", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["RPE", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["RPE", {
                 Toolbox`metabolite["ru5p-D", "c"]}, {
                 Toolbox`metabolite["xu5p-D", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["RPE", {
               Toolbox`metabolite["ru5p-D", "c"]}, {
               Toolbox`metabolite["xu5p-D", "c"]}, {1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {65.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"RPI\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["r5p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["r5p", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["ru5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["ru5p-D", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["RPI", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["RPI", {
                 Toolbox`metabolite["r5p", "c"]}, {
                 Toolbox`metabolite["ru5p-D", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["RPI", {
               Toolbox`metabolite["r5p", "c"]}, {
               Toolbox`metabolite["ru5p-D", "c"]}, {1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {66.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"SUCCt2_2\"", FontSize -> Scaled[0.01], StripOnInput -> False],
              BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "e"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["SUCCt2_2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["SUCCt2_2", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["succ", "e"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["succ", "c"]}, {2, 1, 2, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["SUCCt2_2", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["succ", "e"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["succ", "c"]}, {2, 1, 2, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {67.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"SUCCt3\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "e"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["SUCCt3", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["SUCCt3", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["succ", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["succ", "e"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["SUCCt3", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["succ", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["succ", "e"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {68.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"SUCDi\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["fum", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["q8h2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["q8h2", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["SUCDi", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["SUCDi", {
                 Toolbox`metabolite["succ", "c"], 
                 Toolbox`metabolite["q8", "c"]}, {
                 Toolbox`metabolite["fum", "c"], 
                 Toolbox`metabolite["q8h2", "c"]}, {1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["SUCDi", {
               Toolbox`metabolite["succ", "c"], 
               Toolbox`metabolite["q8", "c"]}, {
               Toolbox`metabolite["fum", "c"], 
               Toolbox`metabolite["q8h2", "c"]}, {1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {69.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"SUCOAS\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["coa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["coa", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succ", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["pi", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["succoa", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["succoa", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["SUCOAS", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["SUCOAS", {
                 Toolbox`metabolite["coa", "c"], 
                 Toolbox`metabolite["succ", "c"], 
                 Toolbox`metabolite["atp", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["pi", "c"], 
                 Toolbox`metabolite["succoa", "c"]}, {1, 1, 1, 1, 1, 1}, 
                True], Editable -> False, Selectable -> False], StandardForm],
              StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["SUCOAS", {
               Toolbox`metabolite["coa", "c"], 
               Toolbox`metabolite["succ", "c"], 
               Toolbox`metabolite["atp", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["pi", "c"], 
               Toolbox`metabolite["succoa", "c"]}, {1, 1, 1, 1, 1, 1}, True]],
             "Tooltip"]& ], TraditionalForm]}, {70.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"TALA\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["s7p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["s7p", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["e4p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["e4p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["TALA", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["TALA", {
                 Toolbox`metabolite["g3p", "c"], 
                 Toolbox`metabolite["s7p", "c"]}, {
                 Toolbox`metabolite["e4p", "c"], 
                 Toolbox`metabolite["f6p", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["TALA", {
               Toolbox`metabolite["g3p", "c"], 
               Toolbox`metabolite["s7p", "c"]}, {
               Toolbox`metabolite["e4p", "c"], 
               Toolbox`metabolite["f6p", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {71.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"THD2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "e"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadh", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    RowBox[{"2", " ", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nad", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nad", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["THD2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["THD2", {
                 Toolbox`metabolite["h", "e"], 
                 Toolbox`metabolite["nadp", "c"], 
                 Toolbox`metabolite["nadh", "c"]}, {
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nad", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {2, 1, 1, 2, 1, 1}, 
                False], Editable -> False, Selectable -> False], 
              StandardForm], StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["THD2", {
               Toolbox`metabolite["h", "e"], 
               Toolbox`metabolite["nadp", "c"], 
               Toolbox`metabolite["nadh", "c"]}, {
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nad", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {2, 1, 1, 2, 1, 1}, False]],
             "Tooltip"]& ], TraditionalForm]}, {72.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"TKT1\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["r5p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["r5p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["xu5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["xu5p-D", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["s7p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["s7p", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["TKT1", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["TKT1", {
                 Toolbox`metabolite["r5p", "c"], 
                 Toolbox`metabolite["xu5p-D", "c"]}, {
                 Toolbox`metabolite["g3p", "c"], 
                 Toolbox`metabolite["s7p", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["TKT1", {
               Toolbox`metabolite["r5p", "c"], 
               Toolbox`metabolite["xu5p-D", "c"]}, {
               Toolbox`metabolite["g3p", "c"], 
               Toolbox`metabolite["s7p", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {73.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"TKT2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["e4p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["e4p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["xu5p-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["xu5p-D", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["f6p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["f6p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["g3p", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["TKT2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["TKT2", {
                 Toolbox`metabolite["e4p", "c"], 
                 Toolbox`metabolite["xu5p-D", "c"]}, {
                 Toolbox`metabolite["f6p", "c"], 
                 Toolbox`metabolite["g3p", "c"]}, {1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["TKT2", {
               Toolbox`metabolite["e4p", "c"], 
               Toolbox`metabolite["xu5p-D", "c"]}, {
               Toolbox`metabolite["f6p", "c"], 
               Toolbox`metabolite["g3p", "c"]}, {1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {74.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"TPI\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["dhap", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["dhap", "c"], Editable -> False, 
                   Selectable -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["g3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["g3p", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["TPI", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["TPI", {
                 Toolbox`metabolite["dhap", "c"]}, {
                 Toolbox`metabolite["g3p", "c"]}, {1, 1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["TPI", {
               Toolbox`metabolite["dhap", "c"]}, {
               Toolbox`metabolite["g3p", "c"]}, {1, 1}, True]], "Tooltip"]& ],
           TraditionalForm]}, {75.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_ac(e)\"", FontSize -> Scaled[0.01], StripOnInput -> False],
              BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["ac", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["ac", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_ac(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_ac(e)", {}, {
                 Toolbox`metabolite["ac", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_ac(e)", {}, {
               Toolbox`metabolite["ac", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {76.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_acald(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["acald", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["acald", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_acald(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_acald(e)", {}, {
                 Toolbox`metabolite["acald", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_acald(e)", {}, {
               Toolbox`metabolite["acald", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {77.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_akg(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["akg", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["akg", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_akg(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_akg(e)", {}, {
                 Toolbox`metabolite["akg", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_akg(e)", {}, {
               Toolbox`metabolite["akg", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {78.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_co2(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["co2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["co2", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_co2(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_co2(e)", {}, {
                 Toolbox`metabolite["co2", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_co2(e)", {}, {
               Toolbox`metabolite["co2", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {79.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_etoh(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["etoh", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["etoh", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_etoh(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_etoh(e)", {}, {
                 Toolbox`metabolite["etoh", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_etoh(e)", {}, {
               Toolbox`metabolite["etoh", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {80.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_for(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["for", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["for", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_for(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_for(e)", {}, {
                 Toolbox`metabolite["for", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_for(e)", {}, {
               Toolbox`metabolite["for", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {81.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_fru(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["fru", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["fru", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_fru(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_fru(e)", {}, {
                 Toolbox`metabolite["fru", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_fru(e)", {}, {
               Toolbox`metabolite["fru", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {82.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_fum(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["fum", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["fum", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_fum(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_fum(e)", {}, {
                 Toolbox`metabolite["fum", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_fum(e)", {}, {
               Toolbox`metabolite["fum", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {83.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_glc(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["glc-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["glc-D", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_glc(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_glc(e)", {}, {
                 Toolbox`metabolite["glc-D", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_glc(e)", {}, {
               Toolbox`metabolite["glc-D", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {84.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_gln_L(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["gln-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["gln-L", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_gln_L(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_gln_L(e)", {}, {
                 Toolbox`metabolite["gln-L", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_gln_L(e)", {}, {
               Toolbox`metabolite["gln-L", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {85.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_glu_L(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["glu-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["glu-L", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_glu_L(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_glu_L(e)", {}, {
                 Toolbox`metabolite["glu-L", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_glu_L(e)", {}, {
               Toolbox`metabolite["glu-L", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {86.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_h2o(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["h2o", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["h2o", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_h2o(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_h2o(e)", {}, {
                 Toolbox`metabolite["h2o", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_h2o(e)", {}, {
               Toolbox`metabolite["h2o", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {87.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_h(e)\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["h", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_h(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_h(e)", {}, {
                 Toolbox`metabolite["h", "e"]}, {1}, True], Editable -> False,
                Selectable -> False], StandardForm], StandardForm, Editable -> 
             True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_h(e)", {}, {
               Toolbox`metabolite["h", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {88.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_lac_D(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["lac-D", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["lac-D", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_lac_D(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_lac_D(e)", {}, {
                 Toolbox`metabolite["lac-D", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_lac_D(e)", {}, {
               Toolbox`metabolite["lac-D", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {89.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_mal_L(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["mal-L", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["mal-L", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_mal_L(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_mal_L(e)", {}, {
                 Toolbox`metabolite["mal-L", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_mal_L(e)", {}, {
               Toolbox`metabolite["mal-L", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {90.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_nh4(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["nh4", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["nh4", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_nh4(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_nh4(e)", {}, {
                 Toolbox`metabolite["nh4", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_nh4(e)", {}, {
               Toolbox`metabolite["nh4", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {91.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_o2(e)\"", FontSize -> Scaled[0.01], StripOnInput -> False],
              BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["o2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["o2", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_o2(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_o2(e)", {}, {
                 Toolbox`metabolite["o2", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_o2(e)", {}, {
               Toolbox`metabolite["o2", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {92.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_pi(e)\"", FontSize -> Scaled[0.01], StripOnInput -> False],
              BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["pi", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["pi", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_pi(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_pi(e)", {}, {
                 Toolbox`metabolite["pi", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_pi(e)", {}, {
               Toolbox`metabolite["pi", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {93.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_pyr(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["pyr", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["pyr", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_pyr(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_pyr(e)", {}, {
                 Toolbox`metabolite["pyr", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_pyr(e)", {}, {
               Toolbox`metabolite["pyr", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {94.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_succ(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["succ", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["e", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["succ", "e"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_succ(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_succ(e)", {}, {
                 Toolbox`metabolite["succ", "e"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_succ(e)", {}, {
               Toolbox`metabolite["succ", "e"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}, {95.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"GLYK\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["atp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["atp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glyc", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glyc", "c"], Editable -> False, 
                    Selectable -> False]}], "\[RightArrow]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["adp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["adp", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glyc3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glyc3p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["GLYK", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["GLYK", {
                 Toolbox`metabolite["atp", "c"], 
                 Toolbox`metabolite["glyc", "c"]}, {
                 Toolbox`metabolite["adp", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["glyc3p", "c"]}, {1, 1, 1, 1, 1}, False], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["GLYK", {
               Toolbox`metabolite["atp", "c"], 
               Toolbox`metabolite["glyc", "c"]}, {
               Toolbox`metabolite["adp", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["glyc3p", "c"]}, {1, 1, 1, 1, 1}, False]], 
            "Tooltip"]& ], TraditionalForm]}, {96.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"G3PD2\"", FontSize -> Scaled[0.01], StripOnInput -> False], 
             BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["glyc3p", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["glyc3p", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadp", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadp", "c"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                  RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["dhap", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["dhap", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["h", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["h", "c"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["nadph", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`metabolite["nadph", "c"], Editable -> False, 
                    Selectable -> False]}]}], 
                StyleBox["G3PD2", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["G3PD2", {
                 Toolbox`metabolite["nadp", "c"], 
                 Toolbox`metabolite["glyc3p", "c"]}, {
                 Toolbox`metabolite["dhap", "c"], 
                 Toolbox`metabolite["h", "c"], 
                 Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True], 
               Editable -> False, Selectable -> False], StandardForm], 
             StandardForm, Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["G3PD2", {
               Toolbox`metabolite["nadp", "c"], 
               Toolbox`metabolite["glyc3p", "c"]}, {
               Toolbox`metabolite["dhap", "c"], 
               Toolbox`metabolite["h", "c"], 
               Toolbox`metabolite["nadph", "c"]}, {1, 1, 1, 1, 1}, True]], 
            "Tooltip"]& ], TraditionalForm]}, {97.5, 
         FormBox[
          TagBox[
           TooltipBox[
            RotationBox[
             StyleBox[
             "\"EX_glyc(e)\"", FontSize -> Scaled[0.01], StripOnInput -> 
              False], BoxRotation -> 1.5707963267948966`], 
            TagBox[
             FormBox[
              InterpretationBox[
               OverscriptBox[
                RowBox[{
                  StyleBox["\[EmptySet]", 
                   GrayLevel[0], StripOnInput -> False], "\[Equilibrium]", 
                  InterpretationBox[
                   SuperscriptBox[
                    StyleBox["glyc", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["c", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                   Toolbox`metabolite["glyc", "c"], Editable -> False, 
                   Selectable -> False]}], 
                StyleBox["EX_glyc(e)", 
                 RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
                 False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
               Toolbox`reaction["EX_glyc(e)", {}, {
                 Toolbox`metabolite["glyc", "c"]}, {1}, True], Editable -> 
               False, Selectable -> False], StandardForm], StandardForm, 
             Editable -> True]], Annotation[#, 
            StandardForm[
             Toolbox`reaction["EX_glyc(e)", {}, {
               Toolbox`metabolite["glyc", "c"]}, {1}, True]], "Tooltip"]& ], 
          TraditionalForm]}}, {{19.5, 
         FormBox["20", TraditionalForm]}, {39.5, 
         FormBox["40", TraditionalForm]}, {59.5, 
         FormBox["60", TraditionalForm]}, {79.5, 
         FormBox["80", TraditionalForm]}}}}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImageSize -> 700, 
    Method -> {
     "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
      "DefaultPlotStyle" -> Automatic, "DomainPadding" -> Scaled[0.02], 
      "RangePadding" -> Scaled[0.05]}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(i, j\\)]\\) = 0\"", 
       "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(\\(i\\)\\(,\\)\\(j\\)\\(\\\\ \
\\)\\)]\\)> 0\"", 
       "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(\\(i\\)\\(,\\)\\(j\\)\\(\\\\ \
\\)\\)]\\)< 0\""}, "SwatchLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                   True, FrameStyle -> GrayLevel[0.6666666666666666], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[1]"], 
                 Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                 Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                 With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                GrayLevel[1], Editable -> False, Selectable -> False], ",", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                   True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[0, 1, 0], Editable -> False, Selectable -> False], 
               ",", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                   True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[1, 0, 0], Editable -> False, Selectable -> False]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& ), Editable -> 
      True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6775728919888506`*^9}]
}, Open  ]],

Cell[TextData[{
 "Dieses Modell eignet sich als Ausgangspunkt f\[UDoubleDot]r eine Vielzahl \
systembiologischer Untersuchungen, etwa ",
 StyleBox["Flux-Balance",
  FontSlant->"Italic"],
 "-Analysen und die Vorhersage von Wachstumsraten f\[UDoubleDot]r \
Knock-Out-Mutanten (siehe z. B. Palsson 2008). Wir beschr\[ADoubleDot]nken \
uns hier auf eine topologische Analyse des aus der \
st\[ODoubleDot]chiometrischen Matrix abgleiteten Netzwerks. Dazu speichern \
wir die Matrix ",
 StyleBox["S",
  FontSlant->"Italic"],
 " in der Variablen ",
 StyleBox["mat1",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.6774859730168257`*^9, 3.6774859774004335`*^9}, {
  3.6774860147166986`*^9, 3.6774860232031136`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mat1", " ", "=", " ", 
   RowBox[{"ecoli", "[", "\"\<Stoichiometry\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616994345603819*^9, 3.616994367095072*^9}, {
  3.6230483756373672`*^9, 3.6230483764552717`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "mat1", "]"}]], "Input",
 CellChangeTimes->{{3.616994368104128*^9, 3.6169943756396217`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"74", ",", "98"}], "}"}]], "Output",
 CellChangeTimes->{3.677572892690852*^9}]
}, Open  ]],

Cell[TextData[{
 "Das Modell enth\[ADoubleDot]lt also 74 Metaboliten, die \[UDoubleDot]ber 98 \
biochemische Reaktionen verbunden sind. Die Multiplikation der \
st\[ODoubleDot]chiometrischen Matrix mit ihrer transponierten Matrix, also ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["SS",
     FontSlant->"Italic"], "T"], TraditionalForm]]],
 ", f\[UDoubleDot]hrt auf eine 74",
 "\[Times]",
 "74-Matrix, die angibt, wie Metaboliten untereinander verbunden sind."
}], "Text",
 CellChangeTimes->{{3.6774862026346292`*^9, 3.6774862075330377`*^9}, {
  3.677486238908693*^9, 3.677486299421199*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mat2", " ", "=", " ", 
   RowBox[{"mat1", ".", 
    RowBox[{"Transpose", "[", "mat1", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616994636820464*^9, 3.616994650550786*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "mat2", "]"}]], "Input",
 CellChangeTimes->{{3.616994652121397*^9, 3.61699465514464*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"74", ",", "74"}], "}"}]], "Output",
 CellChangeTimes->{3.677572892706452*^9}]
}, Open  ]],

Cell["\<\
Unterscheidet man nun nur zwischen Eintr\[ADoubleDot]gen, die Null oder von \
Null verschieden sind, und entfernt die Diagonalelemente, so \
erh\[ADoubleDot]lt man die Adjazenzmatrix des metabolitenzentrischen Graphen.\
\>", "Text",
 CellChangeTimes->{{3.6774863209502373`*^9, 3.6774863447100787`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mat3", " ", "=", " ", 
   RowBox[{"mat2", " ", "/.", " ", 
    RowBox[{"n1_Real", " ", "\[RuleDelayed]", "    ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"n1", "\[Equal]", "0."}], ",", "0", ",", "1"}], "]"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.61699468438209*^9, 3.616994775245207*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"adX", " ", "=", " ", 
   RowBox[{"mat3", "-", 
    RowBox[{"DiagonalMatrix", "[", 
     RowBox[{"Diagonal", "[", "mat3", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.621913106782427*^9, 3.621913110012103*^9}, 
   3.623048870631237*^9, 3.6705094039587765`*^9, 3.677559922640538*^9}],

Cell[TextData[{
 "Wendet man dieselben Operationen auf das Produkt ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["S", "T"], "S"}], TraditionalForm]]],
 " an, so erh\[ADoubleDot]lt man die Adjazenzmatrix des reaktionszentrischen \
Graphen, eine 98\[Times]98-Matrix, die angibt, wie Reaktionen \
\[UDoubleDot]ber ihre Metaboliten miteinander verbunden sind. Wenden wir nun \
den Befehl ",
 StyleBox["AdjacencyGraph",
  FontWeight->"Bold"],
 " auf die Adjazenzmatrix des metabolitenzentrischen Graphen an, so erhalten \
wir das in Abb. 5.37b dargestellte Netzwerk",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[".", "a"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.677486385849351*^9, 3.6774864668446937`*^9}, {
  3.6775606691412354`*^9, 3.6775606740585165`*^9}, {3.6775697189062304`*^9, 
  3.6775697512294874`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"network", "=", 
   StyleBox[
    RowBox[{"AdjacencyGraph", "[", "adX", "]"}],
    FontWeight->"Bold"]}]}]], "Input",
 CellChangeTimes->{{3.677559752896829*^9, 3.677559767258651*^9}, {
   3.6775599776546845`*^9, 3.6775599821459417`*^9}, {3.677560189286789*^9, 
   3.6775601906218653`*^9}, 3.6775616214276276`*^9},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
       20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37,
       38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
       56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73,
       74}, {Null, 
       SparseArray[
       Automatic, {74, 74}, 0, {
        1, {{0, 8, 11, 35, 42, 47, 53, 56, 60, 61, 90, 93, 99, 134, 161, 164, 
          170, 176, 196, 197, 228, 233, 257, 262, 265, 291, 299, 305, 308, 
          311, 319, 322, 348, 372, 375, 399, 405, 430, 433, 440, 492, 525, 
          566, 567, 575, 580, 583, 598, 601, 632, 664, 674, 675, 681, 682, 
          707, 734, 767, 798, 801, 826, 832, 845, 879, 910, 942, 945, 954, 
          963, 968, 971, 980, 986, 990, 996}, CompressedData["
1:eJx1U1l62jAQBsRWgRzims2kBEqAkQpxLUrBDngJpCyPPUIu0Ev3IB3JGNoP
+mTMv8zMP+P++6+f77lMJvObZDJZfBLWA9cLIyKW2RxlhtVo9/qDIQhXLpae
vwqjuGCCkOs43xcyLlUZ8LAI/AO1mmVSrjLj3kRNR4nGIJyL7F5MipRZXpgl
RVo1aopmI+1pCBzdZ5oXIHF3OBLK7tLKXExSVIEGcAYC32jFArHIU/YRn5NT
obWimKRMdSPXfWh/G2SsShjW1Wxv+3KLu1ETuMYb9qdrBqu3eyC8kFoPwP0O
8PbSf8Q2nWCz7QLPJsq2fSUkhVOgn/9F+kufpFE/aeQ8LhuoSmd0MPorK4Qx
HaqnD7IkXywh7a6G+dcbrbbdeeg+6nhHYy6ena+unCvZi87gdbP9cSiWkN9s
KeJwBGKakJCSMnIkX6AVZtT0Tu2uthsD/6Lins3TLjZbUTHMsZBBzJ9dPwI+
pabVRaJAw4UfxcAdHQvaNNOtTh15MdipSgqvX7buuMmcaqdHZgyGQn7zwniG
2PfNdq78dF/JhrCjk1tOIfq8cHlp1AmETVTZrdNLLuN1d5Z2TlrVp97Ui9Lj
vsn1R7HW282bchXvmZ574oUY305fup76xqXrQ7+RSnoX/01FnmM5Ave6ynMe
RNv0xwa5qz3wQAldD+dSf6zfGIRHVpdhfPgD4L2cTQ==
          "]}, Pattern}]}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw9k4sz1AkAx/f9so/f2kc0NVF3KanOdeX08PuuHizpoaTG80JKIsp7L0Kt
SiPLpvRCSJSr0enUSMkpZVXXnUacHqsu11kr18Z6dG7m5r4zn/n+AZ/v13Zr
tHcYjUKheEzwb09aVm5t6OMjom5N7HymEM/jIr9P95RDF6C+OlXAhcrHiefD
EkM3M26lO8HF3gvpkoobEpTJbGc/caOjVvVlbYFJCjdKw8tyZw7ybJcWpipo
8POWHl2wk4orrGMH4tsGSddmXZYhkorhfXdPaKyk4LtsqmQbCCTuyt0wHjUZ
wgyzg8FZjpFnChvCUgT/y/Q3cioDG34eMBcXELBR9Bdvc+whdU+VLxpjuUhM
m8xU9IyQuSvsKS0v+QhLn21kOLKRpU/LDV8vRHycdkUak4PHRdve3T/IgMNH
2256KYEf9bt515V8lAfBGEgzk1N7u3yiRSLMSm6wb1V9JD0ojy22aAhEfhLd
uLT9M3nt8OqIGpEMlP/ibjoWJrgjQFhAxMHm3+joEnXUBDLF2K213hOgJ9Cf
HeFA1YoxJ5ar2LKGhTMtCVmLhngIPXc8NS5bDJehdTlJiVSs+imEMAos0aJb
HhVyX4wM0uXrugIGDIWqxtPJBFSa9JBl0QJEj1/59IjPRMlYm68xfoTMflGv
eysyk/1OJYNJNsOktHOa87rXUpibVf6PCkzkEJG1anEyBVUlqDa7cxDreEhf
lzJIkpvymyVqC3jNs3NccVGM0M4mv7kGNrp9dGq8JSDadzR562M6yt1SUo57
SbCj9bvD/V0D5LiW/dYwmUBFs+5520UuVhs995ZGccHSWmUGS4WwvqepdvhL
gO7qk9OWMnl48G6+cdkJKhZ51ZlvOxD4NXJj+7VWDgLG8lOjFUPkrgt7pl+2
56DwVv3pb6pY6OI2FbUqGUhdNEcrCWSjqKcsdXiWEP6vq+ad92Jh3E8j/fuA
BPIGi/AptRLQGl+/kb0XQrpNvfP2YjO5Me6eSd9AwblXm72JlQy09xnHtrwb
IPPKd7pYxbOxNH7O+kQlB8VfefB3l9Aw5VZfOSfPTGZFD/qf9f1M6k3OoQOk
BTTDxWt3dLIgU79a8nsCgYDA4oXV+Ww0XZ12PoZuCderG/fzrghRH6z6ovK6
HOEPap35h+T45G0fzK4cISt8PEtjfhD+v5OI/lOZOQ8k2H5n0v41OhFS9Pdn
9zbS8Eh3ZFzrKsYrWXCfRx4NTw/eLIpZwsetJ5dO8EqZMC3oi7qbIIBylh+z
6iUVBnqG40OChrLVzxJtRk1kDkfkcW2GJYKKacP1bUx0LqzffDtBBmV++h9j
ool/dR+rXC9korvPSva+jI61hg6Zax0fmXOzA0szOWifG6qt9LWAOaqCpx5l
IzJH3RuYRIAW3lQzenrCh1hu6LIcIU8u5HcoEthY/Gy6+f1NGnov3Gt/6MnD
1F/cewkzHUcWpNbatFlALq/qn/lGDruO+rwgHzrSYijPz1h/JEf1H0KcIhl4
mmIqaanlYsDkRKn+k4Jvj86knRqQw3eG0K6ljImgmJqs7W0TfvI1IbsCxGiJ
8ShM2iOC0k599kMPgX8Anzr64A==
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
         {Arrowheads[0.], ArrowBox[{1, 3}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 13}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{1, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{2, 3}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{2, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{2, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 10}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 13}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 14}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 22}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{3, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 5}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 18}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 61}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{4, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{5, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{5, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{5, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{5, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 7}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 12}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 13}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{6, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{7, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{7, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{8, 9}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{8, 10}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{8, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{8, 23}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 12}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 13}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 14}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 17}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 18}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 22}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 27}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 39}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{10, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{11, 17}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{11, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{11, 44}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{12, 13}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{12, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{12, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{12, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 14}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 16}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 18}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 22}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 26}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 36}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 73}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{13, 74}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 15}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 22}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 44}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{14, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{15, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{15, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{16, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{16, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{16, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{16, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{16, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{17, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{17, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{17, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{17, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 19}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 20}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 44}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 61}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{18, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 22}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 27}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 39}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{20, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{21, 26}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{21, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{21, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{21, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{21, 74}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 25}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 69}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{22, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{23, 24}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{23, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{23, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{23, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{24, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{24, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 26}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 29}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 69}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{25, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{26, 32}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{26, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{26, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{26, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{26, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{27, 28}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{27, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{27, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{27, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{28, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{28, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{29, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{29, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 31}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{30, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{31, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{31, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 33}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 69}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{32, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 34}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 35}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{33, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{34, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{34, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 36}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 37}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{35, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{36, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{36, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{36, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{36, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 38}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{37, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{38, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{38, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{39, 40}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{39, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{39, 44}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{39, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{39, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 41}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 46}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 48}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 53}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 59}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 66}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 70}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{40, 73}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 42}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 45}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 46}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 48}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 53}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 59}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 66}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{41, 70}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 43}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 44}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 47}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 53}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{42, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{44, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{44, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{44, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{45, 46}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{45, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{45, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{45, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 48}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 49}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{47, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 50}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{49, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 51}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 55}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 61}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{50, 74}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{51, 52}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{51, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{51, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{51, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{53, 54}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{53, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{53, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 56}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{55, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 57}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{56, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 58}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 62}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 66}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{57, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{58, 59}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{58, 60}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{58, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{58, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{58, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 61}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 69}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{60, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{61, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{61, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{62, 63}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{62, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{62, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{62, 70}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{62, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{63, 64}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{63, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{63, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{63, 73}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{63, 74}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{64, 65}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{64, 67}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{64, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{64, 71}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{65, 74}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{67, 68}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{69, 72}, 0.051518544907723104`]}, 
         {Arrowheads[0.], ArrowBox[{73, 74}, 0.051518544907723104`]}}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.051518544907723104`], DiskBox[2, 0.051518544907723104`],
          DiskBox[3, 0.051518544907723104`], 
         DiskBox[4, 0.051518544907723104`], DiskBox[5, 0.051518544907723104`],
          DiskBox[6, 0.051518544907723104`], 
         DiskBox[7, 0.051518544907723104`], DiskBox[8, 0.051518544907723104`],
          DiskBox[9, 0.051518544907723104`], 
         DiskBox[10, 0.051518544907723104`], 
         DiskBox[11, 0.051518544907723104`], 
         DiskBox[12, 0.051518544907723104`], 
         DiskBox[13, 0.051518544907723104`], 
         DiskBox[14, 0.051518544907723104`], 
         DiskBox[15, 0.051518544907723104`], 
         DiskBox[16, 0.051518544907723104`], 
         DiskBox[17, 0.051518544907723104`], 
         DiskBox[18, 0.051518544907723104`], 
         DiskBox[19, 0.051518544907723104`], 
         DiskBox[20, 0.051518544907723104`], 
         DiskBox[21, 0.051518544907723104`], 
         DiskBox[22, 0.051518544907723104`], 
         DiskBox[23, 0.051518544907723104`], 
         DiskBox[24, 0.051518544907723104`], 
         DiskBox[25, 0.051518544907723104`], 
         DiskBox[26, 0.051518544907723104`], 
         DiskBox[27, 0.051518544907723104`], 
         DiskBox[28, 0.051518544907723104`], 
         DiskBox[29, 0.051518544907723104`], 
         DiskBox[30, 0.051518544907723104`], 
         DiskBox[31, 0.051518544907723104`], 
         DiskBox[32, 0.051518544907723104`], 
         DiskBox[33, 0.051518544907723104`], 
         DiskBox[34, 0.051518544907723104`], 
         DiskBox[35, 0.051518544907723104`], 
         DiskBox[36, 0.051518544907723104`], 
         DiskBox[37, 0.051518544907723104`], 
         DiskBox[38, 0.051518544907723104`], 
         DiskBox[39, 0.051518544907723104`], 
         DiskBox[40, 0.051518544907723104`], 
         DiskBox[41, 0.051518544907723104`], 
         DiskBox[42, 0.051518544907723104`], 
         DiskBox[43, 0.051518544907723104`], 
         DiskBox[44, 0.051518544907723104`], 
         DiskBox[45, 0.051518544907723104`], 
         DiskBox[46, 0.051518544907723104`], 
         DiskBox[47, 0.051518544907723104`], 
         DiskBox[48, 0.051518544907723104`], 
         DiskBox[49, 0.051518544907723104`], 
         DiskBox[50, 0.051518544907723104`], 
         DiskBox[51, 0.051518544907723104`], 
         DiskBox[52, 0.051518544907723104`], 
         DiskBox[53, 0.051518544907723104`], 
         DiskBox[54, 0.051518544907723104`], 
         DiskBox[55, 0.051518544907723104`], 
         DiskBox[56, 0.051518544907723104`], 
         DiskBox[57, 0.051518544907723104`], 
         DiskBox[58, 0.051518544907723104`], 
         DiskBox[59, 0.051518544907723104`], 
         DiskBox[60, 0.051518544907723104`], 
         DiskBox[61, 0.051518544907723104`], 
         DiskBox[62, 0.051518544907723104`], 
         DiskBox[63, 0.051518544907723104`], 
         DiskBox[64, 0.051518544907723104`], 
         DiskBox[65, 0.051518544907723104`], 
         DiskBox[66, 0.051518544907723104`], 
         DiskBox[67, 0.051518544907723104`], 
         DiskBox[68, 0.051518544907723104`], 
         DiskBox[69, 0.051518544907723104`], 
         DiskBox[70, 0.051518544907723104`], 
         DiskBox[71, 0.051518544907723104`], 
         DiskBox[72, 0.051518544907723104`], 
         DiskBox[73, 0.051518544907723104`], 
         DiskBox[74, 0.051518544907723104`]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.6775728928936524`*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "a"], TraditionalForm]]],
 " Tats\[ADoubleDot]chlich wurde das Layout des Graphen f\[UDoubleDot]r \
Abbildung 5.37b noch \[UDoubleDot]ber die folgende Sequenz von Befehlen ver\
\[ADoubleDot]ndert:\n\n",
 StyleBox["SeedRandom[84];\nnetwork1 = Graph[network, GraphLayout -> \
\[OpenCurlyDoubleQuote]RandomEmbedding\[CloseCurlyDoubleQuote]];\n\n\
SeedRandom[464]; \nGraphPlot[network1, \n  VertexRenderingFunction -> \
({LightGray, EdgeForm[Black], \n          Disk[#, .01], Black} &), \n  \
EdgeRenderingFunction -> ({Black, Thickness[0.001], Line[#1]} &), \n  \
ImageSize -> 600]",
  FontWeight->"Bold"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.6775606994619694`*^9, 3.6775607257944756`*^9}, 
   3.677561601209992*^9, {3.6775616851109395`*^9, 3.6775617524884577`*^9}},
 Background->RGBColor[0.87, 0.94, 1]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{444, Automatic}, {Automatic, 189}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 385, 10, 94, "Subtitle"],
Cell[1841, 72, 472, 11, 106, "Text"],
Cell[2316, 85, 179, 3, 52, "Input"],
Cell[2498, 90, 172, 4, 49, "Text"],
Cell[2673, 96, 236, 7, 31, "Input"],
Cell[2912, 105, 678, 19, 144, "Text"],
Cell[CellGroupData[{
Cell[3615, 128, 583, 14, 72, "Input"],
Cell[4201, 144, 156987, 3556, 333, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161225, 3705, 392, 7, 31, "Input"],
Cell[161620, 3714, 486050, 9936, 585, "Output"]
}, Open  ]],
Cell[647685, 13653, 716, 17, 144, "Text"],
Cell[648404, 13672, 252, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[648681, 13681, 134, 2, 31, "Input"],
Cell[648818, 13685, 117, 3, 31, "Output"]
}, Open  ]],
Cell[648950, 13691, 607, 14, 108, "Text"],
Cell[649560, 13707, 214, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[649799, 13716, 131, 2, 31, "Input"],
Cell[649933, 13720, 117, 3, 31, "Output"]
}, Open  ]],
Cell[650065, 13726, 312, 5, 87, "Text"],
Cell[650380, 13733, 349, 9, 31, "Input"],
Cell[650732, 13744, 328, 7, 31, "Input"],
Cell[651063, 13753, 836, 20, 146, "Text"],
Cell[CellGroupData[{
Cell[651924, 13777, 390, 9, 47, "Input"],
Cell[652317, 13788, 42461, 636, 346, "Output"]
}, Open  ]],
Cell[694793, 14427, 869, 18, 350, "Text"]
}, Open  ]]
}
]
*)

